@@ -5,8 +5,8 @@ import (
 	"crypto/tls"
 	"errors"
 	"fmt"
+	"io"
 	"net/http"
-	"net/url"
 	"os"
 	"reflect"
 	"strconv"
@@ -14,7 +14,7 @@ import (
 	"time"
 
 	"github.com/caarlos0/log"
-	"github.com/google/go-github/v74/github"
+	"github.com/google/go-github/v78/github"
 	"github.com/goreleaser/goreleaser/v2/internal/artifact"
 	"github.com/goreleaser/goreleaser/v2/internal/tmpl"
 	"github.com/goreleaser/goreleaser/v2/pkg/config"
@@ -59,8 +59,7 @@ func newGitHub(ctx *context.Context, token string) (*githubClient, error) {
 	base.(*http.Transport).Proxy = http.ProxyFromEnvironment
 	httpClient.Transport.(*oauth2.Transport).Base = base
 
-	client := github.NewClient(httpClient)
-	err := overrideGitHubClientAPI(ctx, client)
+	client, err := setEnterpriseURLs(ctx, github.NewClient(httpClient))
 	if err != nil {
 		return &githubClient{}, err
 	}
@@ -68,6 +67,21 @@ func newGitHub(ctx *context.Context, token string) (*githubClient, error) {
 	return &githubClient{client: client}, nil
 }
 
+func setEnterpriseURLs(ctx *context.Context, client *github.Client) (*github.Client, error) {
+	if ctx.Config.GitHubURLs.API == "" {
+		return client, nil
+	}
+	baseURL, err := tmpl.New(ctx).Apply(ctx.Config.GitHubURLs.API)
+	if err != nil {
+		return nil, fmt.Errorf("templating GitHub API URL: %w", err)
+	}
+	uploadURL, err := tmpl.New(ctx).Apply(ctx.Config.GitHubURLs.Upload)
+	if err != nil {
+		return nil, fmt.Errorf("templating GitHub upload URL: %w", err)
+	}
+	return client.WithEnterpriseURLs(baseURL, uploadURL)
+}
+
 func (c *githubClient) checkRateLimit(ctx *context.Context) {
 	limits, _, err := c.client.RateLimit.Get(ctx)
 	if err != nil {
@@ -255,7 +269,7 @@ func (c *githubClient) SyncFork(ctx *context.Context, head, base Repo) error {
 		}
 		branch = def
 	}
-	res, _, err := c.client.Repositories.MergeUpstream(
+	res, resp, err := c.client.Repositories.MergeUpstream(
 		ctx,
 		head.Owner,
 		head.Name,
@@ -263,12 +277,13 @@ func (c *githubClient) SyncFork(ctx *context.Context, head, base Repo) error {
 			Branch: github.Ptr(branch),
 		},
 	)
-	if res != nil {
-		log.WithField("merge_type", res.GetMergeType()).
-			WithField("base_branch", res.GetBaseBranch()).
-			Info(res.GetMessage())
+	if err != nil {
+		return fmt.Errorf("%w: %s", err, bodyOf(resp))
 	}
-	return err
+	log.WithField("merge_type", res.GetMergeType()).
+		WithField("base_branch", res.GetBaseBranch()).
+		Info(res.GetMessage())
+	return nil
 }
 
 func (c *githubClient) CreateFile(
@@ -291,14 +306,19 @@ func (c *githubClient) CreateFile(
 	}
 
 	options := &github.RepositoryContentFileOptions{
-		Committer: &github.CommitAuthor{
-			Name:  github.Ptr(commitAuthor.Name),
-			Email: github.Ptr(commitAuthor.Email),
-		},
 		Content: content,
 		Message: github.Ptr(message),
 	}
 
+	// When using a GitHub App token, omit the committer to get automatic signed commits
+	// See: https://docs.github.com/en/authentication/managing-commit-signature-verification/about-commit-signature-verification#signature-verification-for-bots
+	if !commitAuthor.UseGitHubAppToken {
+		options.Committer = &github.CommitAuthor{
+			Name:  github.Ptr(commitAuthor.Name),
+			Email: github.Ptr(commitAuthor.Email),
+		}
+	}
+
 	// Set the branch if we got it above...otherwise, just default to
 	// whatever the SDK does auto-magically
 	if branch != "" {
@@ -323,15 +343,13 @@ func (c *githubClient) CreateFile(
 				return fmt.Errorf("could not get ref %q: %w", "refs/heads/"+defBranch, err)
 			}
 
-			if _, _, err := c.client.Git.CreateRef(ctx, repo.Owner, repo.Name, &github.Reference{
-				Ref: github.Ptr("refs/heads/" + branch),
-				Object: &github.GitObject{
-					SHA: defRef.Object.SHA,
-				},
+			if _, resp, err := c.client.Git.CreateRef(ctx, repo.Owner, repo.Name, github.CreateRef{
+				Ref: "refs/heads/" + branch,
+				SHA: defRef.Object.GetSHA(),
 			}); err != nil {
 				rerr := new(github.ErrorResponse)
 				if !errors.As(err, &rerr) || rerr.Message != "Reference already exists" {
-					return fmt.Errorf("could not create ref %q from %q: %w", "refs/heads/"+branch, defRef.Object.GetSHA(), err)
+					return fmt.Errorf("could not create ref %q from %q: %w: %s", "refs/heads/"+branch, defRef.Object.GetSHA(), err, bodyOf(resp))
 				}
 			}
 		}
@@ -640,35 +658,6 @@ func (c *githubClient) getMilestoneByTitle(ctx *context.Context, repo Repo, titl
 	return nil, nil
 }
 
-func overrideGitHubClientAPI(ctx *context.Context, client *github.Client) error {
-	if ctx.Config.GitHubURLs.API == "" {
-		return nil
-	}
-
-	apiURL, err := tmpl.New(ctx).Apply(ctx.Config.GitHubURLs.API)
-	if err != nil {
-		return fmt.Errorf("templating GitHub API URL: %w", err)
-	}
-	api, err := url.Parse(apiURL)
-	if err != nil {
-		return err
-	}
-
-	uploadURL, err := tmpl.New(ctx).Apply(ctx.Config.GitHubURLs.Upload)
-	if err != nil {
-		return fmt.Errorf("templating GitHub upload URL: %w", err)
-	}
-	upload, err := url.Parse(uploadURL)
-	if err != nil {
-		return err
-	}
-
-	client.BaseURL = api
-	client.UploadURL = upload
-
-	return nil
-}
-
 func (c *githubClient) deleteExistingDraftRelease(ctx *context.Context, name string) error {
 	c.checkRateLimit(ctx)
 	release, err := c.findDraftRelease(ctx, name)
@@ -725,3 +714,12 @@ func githubErrLogger(resp *github.Response, err error) *log.Entry {
 	}
 	return log.WithField("request-id", requestID).WithError(err)
 }
+
+func bodyOf(resp *github.Response) string {
+	if resp == nil || resp.Body == nil {
+		return "no response"
+	}
+	defer resp.Body.Close()
+	bts, _ := io.ReadAll(resp.Body)
+	return string(bts)
+}
