@@ -13,7 +13,7 @@ import (
 	"text/template"
 	"time"
 
-	"github.com/google/go-github/v74/github"
+	"github.com/google/go-github/v78/github"
 	"github.com/goreleaser/goreleaser/v2/internal/artifact"
 	"github.com/goreleaser/goreleaser/v2/internal/testctx"
 	"github.com/goreleaser/goreleaser/v2/internal/testlib"
@@ -26,21 +26,21 @@ import (
 func TestNewGitHubClient(t *testing.T) {
 	t.Run("good urls", func(t *testing.T) {
 		githubURL := "https://github.mycompany.com"
-		ctx := testctx.NewWithCfg(config.Project{
+		ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 			GitHubURLs: config.GitHubURLs{
-				API:    githubURL + "/api",
-				Upload: githubURL + "/upload",
+				API:    githubURL + "/api/v3",
+				Upload: githubURL,
 			},
 		})
 
 		client, err := newGitHub(ctx, ctx.Token)
 		require.NoError(t, err)
-		require.Equal(t, githubURL+"/api", client.client.BaseURL.String())
-		require.Equal(t, githubURL+"/upload", client.client.UploadURL.String())
+		require.Equal(t, githubURL+"/api/v3/", client.client.BaseURL.String())
+		require.Equal(t, githubURL+"/api/uploads/", client.client.UploadURL.String())
 	})
 
 	t.Run("bad api url", func(t *testing.T) {
-		ctx := testctx.NewWithCfg(config.Project{
+		ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 			GitHubURLs: config.GitHubURLs{
 				API:    "://github.mycompany.com/api",
 				Upload: "https://github.mycompany.com/upload",
@@ -52,7 +52,7 @@ func TestNewGitHubClient(t *testing.T) {
 	})
 
 	t.Run("bad upload url", func(t *testing.T) {
-		ctx := testctx.NewWithCfg(config.Project{
+		ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 			GitHubURLs: config.GitHubURLs{
 				API:    "https://github.mycompany.com/api",
 				Upload: "not a url:4994",
@@ -65,10 +65,10 @@ func TestNewGitHubClient(t *testing.T) {
 
 	t.Run("template", func(t *testing.T) {
 		githubURL := "https://github.mycompany.com"
-		ctx := testctx.NewWithCfg(config.Project{
+		ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 			Env: []string{
-				fmt.Sprintf("GORELEASER_TEST_GITHUB_URLS_API=%s/api", githubURL),
-				fmt.Sprintf("GORELEASER_TEST_GITHUB_URLS_UPLOAD=%s/upload", githubURL),
+				fmt.Sprintf("GORELEASER_TEST_GITHUB_URLS_API=%s", githubURL),
+				fmt.Sprintf("GORELEASER_TEST_GITHUB_URLS_UPLOAD=%s", githubURL),
 			},
 			GitHubURLs: config.GitHubURLs{
 				API:    "{{ .Env.GORELEASER_TEST_GITHUB_URLS_API }}",
@@ -78,12 +78,12 @@ func TestNewGitHubClient(t *testing.T) {
 
 		client, err := newGitHub(ctx, ctx.Token)
 		require.NoError(t, err)
-		require.Equal(t, githubURL+"/api", client.client.BaseURL.String())
-		require.Equal(t, githubURL+"/upload", client.client.UploadURL.String())
+		require.Equal(t, githubURL+"/api/v3/", client.client.BaseURL.String())
+		require.Equal(t, githubURL+"/api/uploads/", client.client.UploadURL.String())
 	})
 
 	t.Run("template invalid api", func(t *testing.T) {
-		ctx := testctx.NewWithCfg(config.Project{
+		ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 			GitHubURLs: config.GitHubURLs{
 				API: "{{ .Env.GORELEASER_NOT_EXISTS }}",
 			},
@@ -94,7 +94,7 @@ func TestNewGitHubClient(t *testing.T) {
 	})
 
 	t.Run("template invalid upload", func(t *testing.T) {
-		ctx := testctx.NewWithCfg(config.Project{
+		ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 			GitHubURLs: config.GitHubURLs{
 				API:    "https://github.mycompany.com/api",
 				Upload: "{{ .Env.GORELEASER_NOT_EXISTS }}",
@@ -106,7 +106,7 @@ func TestNewGitHubClient(t *testing.T) {
 	})
 
 	t.Run("template invalid", func(t *testing.T) {
-		ctx := testctx.NewWithCfg(config.Project{
+		ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 			GitHubURLs: config.GitHubURLs{
 				API: "{{.dddddddddd",
 			},
@@ -118,7 +118,7 @@ func TestNewGitHubClient(t *testing.T) {
 }
 
 func TestGitHubUploadReleaseIDNotInt(t *testing.T) {
-	ctx := testctx.New()
+	ctx := testctx.Wrap(t.Context())
 	client, err := newGitHub(ctx, ctx.Token)
 	require.NoError(t, err)
 
@@ -160,7 +160,7 @@ func TestGitHubReleaseURLTemplate(t *testing.T) {
 
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			ctx := testctx.NewWithCfg(config.Project{
+			ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 				Env: []string{
 					"GORELEASER_TEST_GITHUB_URLS_DOWNLOAD=https://github.mycompany.com",
 				},
@@ -190,7 +190,7 @@ func TestGitHubReleaseURLTemplate(t *testing.T) {
 }
 
 func TestGitHubCreateReleaseWrongNameTemplate(t *testing.T) {
-	ctx := testctx.NewWithCfg(config.Project{
+	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		Release: config.Release{
 			NameTemplate: "{{.dddddddddd",
 		},
@@ -209,7 +209,7 @@ func TestGitHubGetDefaultBranch(t *testing.T) {
 		totalRequests++
 		defer r.Body.Close()
 
-		if r.URL.Path == "/rate_limit" {
+		if r.URL.Path == "/api/v3/rate_limit" {
 			w.WriteHeader(http.StatusOK)
 			fmt.Fprint(w, `{"resources":{"core":{"remaining":120}}}`)
 			return
@@ -219,9 +219,9 @@ func TestGitHubGetDefaultBranch(t *testing.T) {
 		w.WriteHeader(http.StatusOK)
 		fmt.Fprint(w, `{"default_branch": "main"}`)
 	}))
-	defer srv.Close()
+	t.Cleanup(srv.Close)
 
-	ctx := testctx.NewWithCfg(config.Project{
+	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
 			API: srv.URL + "/",
 		},
@@ -249,9 +249,9 @@ func TestGitHubGetDefaultBranchErr(t *testing.T) {
 		w.WriteHeader(http.StatusNotImplemented)
 		fmt.Fprint(w, "{}")
 	}))
-	defer srv.Close()
+	t.Cleanup(srv.Close)
 
-	ctx := testctx.NewWithCfg(config.Project{
+	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
 			API: srv.URL + "/",
 		},
@@ -272,7 +272,7 @@ func TestGitHubChangelog(t *testing.T) {
 	srv := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 		defer r.Body.Close()
 
-		if r.URL.Path == "/repos/someone/something/compare/v1.0.0...v1.1.0" {
+		if r.URL.Path == "/api/v3/repos/someone/something/compare/v1.0.0...v1.1.0" {
 			r, err := os.Open("testdata/github/compare.json")
 			if assert.NoError(t, err) {
 				defer r.Close()
@@ -281,15 +281,15 @@ func TestGitHubChangelog(t *testing.T) {
 			}
 			return
 		}
-		if r.URL.Path == "/rate_limit" {
+		if r.URL.Path == "/api/v3/rate_limit" {
 			w.WriteHeader(http.StatusOK)
 			fmt.Fprint(w, `{"resources":{"core":{"remaining":120}}}`)
 			return
 		}
 	}))
-	defer srv.Close()
+	t.Cleanup(srv.Close)
 
-	ctx := testctx.NewWithCfg(config.Project{
+	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
 			API: srv.URL + "/",
 		},
@@ -319,7 +319,7 @@ func TestGitHubReleaseNotes(t *testing.T) {
 	srv := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 		defer r.Body.Close()
 
-		if r.URL.Path == "/repos/someone/something/releases/generate-notes" {
+		if r.URL.Path == "/api/v3/repos/someone/something/releases/generate-notes" {
 			r, err := os.Open("testdata/github/releasenotes.json")
 			if assert.NoError(t, err) {
 				defer r.Close()
@@ -328,15 +328,15 @@ func TestGitHubReleaseNotes(t *testing.T) {
 			}
 			return
 		}
-		if r.URL.Path == "/rate_limit" {
+		if r.URL.Path == "/api/v3/rate_limit" {
 			w.WriteHeader(http.StatusOK)
 			fmt.Fprint(w, `{"resources":{"core":{"remaining":120}}}`)
 			return
 		}
 	}))
-	defer srv.Close()
+	t.Cleanup(srv.Close)
 
-	ctx := testctx.NewWithCfg(config.Project{
+	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
 			API: srv.URL + "/",
 		},
@@ -358,18 +358,18 @@ func TestGitHubReleaseNotesError(t *testing.T) {
 	srv := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 		defer r.Body.Close()
 
-		if r.URL.Path == "/repos/someone/something/releases/generate-notes" {
+		if r.URL.Path == "/api/v3/repos/someone/something/releases/generate-notes" {
 			w.WriteHeader(http.StatusBadRequest)
 		}
-		if r.URL.Path == "/rate_limit" {
+		if r.URL.Path == "/api/v3/rate_limit" {
 			w.WriteHeader(http.StatusOK)
 			fmt.Fprint(w, `{"resources":{"core":{"remaining":120}}}`)
 			return
 		}
 	}))
-	defer srv.Close()
+	t.Cleanup(srv.Close)
 
-	ctx := testctx.NewWithCfg(config.Project{
+	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
 			API: srv.URL + "/",
 		},
@@ -391,7 +391,7 @@ func TestGitHubCloseMilestone(t *testing.T) {
 		defer r.Body.Close()
 		t.Log(r.URL.Path)
 
-		if r.URL.Path == "/repos/someone/something/milestones" {
+		if r.URL.Path == "/api/v3/repos/someone/something/milestones" {
 			r, err := os.Open("testdata/github/milestones.json")
 			if assert.NoError(t, err) {
 				defer r.Close()
@@ -401,15 +401,15 @@ func TestGitHubCloseMilestone(t *testing.T) {
 			return
 		}
 
-		if r.URL.Path == "/rate_limit" {
+		if r.URL.Path == "/api/v3/rate_limit" {
 			w.WriteHeader(http.StatusOK)
 			fmt.Fprint(w, `{"resources":{"core":{"remaining":120}}}`)
 			return
 		}
 	}))
-	defer srv.Close()
+	t.Cleanup(srv.Close)
 
-	ctx := testctx.NewWithCfg(config.Project{
+	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
 			API: srv.URL + "/",
 		},
@@ -430,7 +430,7 @@ func TestGitHubOpenPullRequestCrossRepo(t *testing.T) {
 	srv := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 		defer r.Body.Close()
 
-		if r.URL.Path == "/repos/someone/something/contents/.github/PULL_REQUEST_TEMPLATE.md" {
+		if r.URL.Path == "/api/v3/repos/someone/something/contents/.github/PULL_REQUEST_TEMPLATE.md" {
 			content := github.RepositoryContent{
 				Encoding: github.Ptr("base64"),
 				Content:  github.Ptr(base64.StdEncoding.EncodeToString([]byte(testPRTemplate))),
@@ -440,7 +440,7 @@ func TestGitHubOpenPullRequestCrossRepo(t *testing.T) {
 			return
 		}
 
-		if r.URL.Path == "/repos/someone/something/pulls" {
+		if r.URL.Path == "/api/v3/repos/someone/something/pulls" {
 			got, err := io.ReadAll(r.Body)
 			assert.NoError(t, err)
 			var pr github.NewPullRequest
@@ -457,7 +457,7 @@ func TestGitHubOpenPullRequestCrossRepo(t *testing.T) {
 			return
 		}
 
-		if r.URL.Path == "/rate_limit" {
+		if r.URL.Path == "/api/v3/rate_limit" {
 			w.WriteHeader(http.StatusOK)
 			fmt.Fprint(w, `{"resources":{"core":{"remaining":120}}}`)
 			return
@@ -465,9 +465,9 @@ func TestGitHubOpenPullRequestCrossRepo(t *testing.T) {
 
 		t.Error("unhandled request: " + r.URL.Path)
 	}))
-	defer srv.Close()
+	t.Cleanup(srv.Close)
 
-	ctx := testctx.NewWithCfg(config.Project{
+	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
 			API: srv.URL + "/",
 		},
@@ -491,7 +491,7 @@ func TestGitHubOpenPullRequestHappyPath(t *testing.T) {
 	srv := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 		defer r.Body.Close()
 
-		if r.URL.Path == "/repos/someone/something/contents/.github/PULL_REQUEST_TEMPLATE.md" {
+		if r.URL.Path == "/api/v3/repos/someone/something/contents/.github/PULL_REQUEST_TEMPLATE.md" {
 			content := github.RepositoryContent{
 				Encoding: github.Ptr("base64"),
 				Content:  github.Ptr(base64.StdEncoding.EncodeToString([]byte(testPRTemplate))),
@@ -501,7 +501,7 @@ func TestGitHubOpenPullRequestHappyPath(t *testing.T) {
 			return
 		}
 
-		if r.URL.Path == "/repos/someone/something/pulls" {
+		if r.URL.Path == "/api/v3/repos/someone/something/pulls" {
 			r, err := os.Open("testdata/github/pull.json")
 			if assert.NoError(t, err) {
 				defer r.Close()
@@ -511,7 +511,7 @@ func TestGitHubOpenPullRequestHappyPath(t *testing.T) {
 			return
 		}
 
-		if r.URL.Path == "/rate_limit" {
+		if r.URL.Path == "/api/v3/rate_limit" {
 			w.WriteHeader(http.StatusOK)
 			fmt.Fprint(w, `{"resources":{"core":{"remaining":120}}}`)
 			return
@@ -519,9 +519,9 @@ func TestGitHubOpenPullRequestHappyPath(t *testing.T) {
 
 		t.Error("unhandled request: " + r.URL.Path)
 	}))
-	defer srv.Close()
+	t.Cleanup(srv.Close)
 
-	ctx := testctx.NewWithCfg(config.Project{
+	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
 			API: srv.URL + "/",
 		},
@@ -541,12 +541,12 @@ func TestGitHubOpenPullRequestNoBaseBranchDraft(t *testing.T) {
 	srv := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 		defer r.Body.Close()
 
-		if r.URL.Path == "/repos/someone/something/contents/.github/PULL_REQUEST_TEMPLATE.md" {
+		if r.URL.Path == "/api/v3/repos/someone/something/contents/.github/PULL_REQUEST_TEMPLATE.md" {
 			w.WriteHeader(http.StatusNotFound)
 			return
 		}
 
-		if r.URL.Path == "/repos/someone/something/pulls" {
+		if r.URL.Path == "/api/v3/repos/someone/something/pulls" {
 			got, err := io.ReadAll(r.Body)
 			assert.NoError(t, err)
 			var pr github.NewPullRequest
@@ -564,13 +564,13 @@ func TestGitHubOpenPullRequestNoBaseBranchDraft(t *testing.T) {
 			return
 		}
 
-		if r.URL.Path == "/repos/someone/something" {
+		if r.URL.Path == "/api/v3/repos/someone/something" {
 			w.WriteHeader(http.StatusOK)
 			fmt.Fprint(w, `{"default_branch": "main"}`)
 			return
 		}
 
-		if r.URL.Path == "/rate_limit" {
+		if r.URL.Path == "/api/v3/rate_limit" {
 			w.WriteHeader(http.StatusOK)
 			fmt.Fprint(w, `{"resources":{"core":{"remaining":120}}}`)
 			return
@@ -578,9 +578,9 @@ func TestGitHubOpenPullRequestNoBaseBranchDraft(t *testing.T) {
 
 		t.Error("unhandled request: " + r.URL.Path)
 	}))
-	defer srv.Close()
+	t.Cleanup(srv.Close)
 
-	ctx := testctx.NewWithCfg(config.Project{
+	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
 			API: srv.URL + "/",
 		},
@@ -601,12 +601,12 @@ func TestGitHubOpenPullRequestPRExists(t *testing.T) {
 	srv := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 		defer r.Body.Close()
 
-		if r.URL.Path == "/repos/someone/something/contents/.github/PULL_REQUEST_TEMPLATE.md" {
+		if r.URL.Path == "/api/v3/repos/someone/something/contents/.github/PULL_REQUEST_TEMPLATE.md" {
 			w.WriteHeader(http.StatusNotFound)
 			return
 		}
 
-		if r.URL.Path == "/repos/someone/something/pulls" {
+		if r.URL.Path == "/api/v3/repos/someone/something/pulls" {
 			w.WriteHeader(http.StatusUnprocessableEntity)
 			r, err := os.Open("testdata/github/pull.json")
 			if assert.NoError(t, err) {
@@ -617,7 +617,7 @@ func TestGitHubOpenPullRequestPRExists(t *testing.T) {
 			return
 		}
 
-		if r.URL.Path == "/rate_limit" {
+		if r.URL.Path == "/api/v3/rate_limit" {
 			w.WriteHeader(http.StatusOK)
 			fmt.Fprint(w, `{"resources":{"core":{"remaining":120}}}`)
 			return
@@ -625,9 +625,9 @@ func TestGitHubOpenPullRequestPRExists(t *testing.T) {
 
 		t.Error("unhandled request: " + r.URL.Path)
 	}))
-	defer srv.Close()
+	t.Cleanup(srv.Close)
 
-	ctx := testctx.NewWithCfg(config.Project{
+	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
 			API: srv.URL + "/",
 		},
@@ -647,12 +647,12 @@ func TestGitHubOpenPullRequestBaseEmpty(t *testing.T) {
 	srv := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 		defer r.Body.Close()
 
-		if r.URL.Path == "/repos/someone/something/contents/.github/PULL_REQUEST_TEMPLATE.md" {
+		if r.URL.Path == "/api/v3/repos/someone/something/contents/.github/PULL_REQUEST_TEMPLATE.md" {
 			w.WriteHeader(http.StatusNotFound)
 			return
 		}
 
-		if r.URL.Path == "/repos/someone/something/pulls" {
+		if r.URL.Path == "/api/v3/repos/someone/something/pulls" {
 			r, err := os.Open("testdata/github/pull.json")
 			if assert.NoError(t, err) {
 				defer r.Close()
@@ -662,13 +662,13 @@ func TestGitHubOpenPullRequestBaseEmpty(t *testing.T) {
 			return
 		}
 
-		if r.URL.Path == "/repos/someone/something" {
+		if r.URL.Path == "/api/v3/repos/someone/something" {
 			w.WriteHeader(http.StatusOK)
 			fmt.Fprint(w, `{"default_branch": "main"}`)
 			return
 		}
 
-		if r.URL.Path == "/rate_limit" {
+		if r.URL.Path == "/api/v3/rate_limit" {
 			w.WriteHeader(http.StatusOK)
 			fmt.Fprint(w, `{"resources":{"core":{"remaining":120}}}`)
 			return
@@ -676,9 +676,9 @@ func TestGitHubOpenPullRequestBaseEmpty(t *testing.T) {
 
 		t.Error("unhandled request: " + r.URL.Path)
 	}))
-	defer srv.Close()
+	t.Cleanup(srv.Close)
 
-	ctx := testctx.NewWithCfg(config.Project{
+	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
 			API: srv.URL + "/",
 		},
@@ -698,12 +698,12 @@ func TestGitHubOpenPullRequestHeadEmpty(t *testing.T) {
 	srv := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 		defer r.Body.Close()
 
-		if r.URL.Path == "/repos/someone/something/contents/.github/PULL_REQUEST_TEMPLATE.md" {
+		if r.URL.Path == "/api/v3/repos/someone/something/contents/.github/PULL_REQUEST_TEMPLATE.md" {
 			w.WriteHeader(http.StatusNotFound)
 			return
 		}
 
-		if r.URL.Path == "/repos/someone/something/pulls" {
+		if r.URL.Path == "/api/v3/repos/someone/something/pulls" {
 			r, err := os.Open("testdata/github/pull.json")
 			if assert.NoError(t, err) {
 				defer r.Close()
@@ -713,13 +713,13 @@ func TestGitHubOpenPullRequestHeadEmpty(t *testing.T) {
 			return
 		}
 
-		if r.URL.Path == "/repos/someone/something" {
+		if r.URL.Path == "/api/v3/repos/someone/something" {
 			w.WriteHeader(http.StatusOK)
 			fmt.Fprint(w, `{"default_branch": "main"}`)
 			return
 		}
 
-		if r.URL.Path == "/rate_limit" {
+		if r.URL.Path == "/api/v3/rate_limit" {
 			w.WriteHeader(http.StatusOK)
 			fmt.Fprint(w, `{"resources":{"core":{"remaining":120}}}`)
 			return
@@ -727,9 +727,9 @@ func TestGitHubOpenPullRequestHeadEmpty(t *testing.T) {
 
 		t.Error("unhandled request: " + r.URL.Path)
 	}))
-	defer srv.Close()
+	t.Cleanup(srv.Close)
 
-	ctx := testctx.NewWithCfg(config.Project{
+	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
 			API: srv.URL + "/",
 		},
@@ -749,23 +749,23 @@ func TestGitHubCreateFileHappyPathCreate(t *testing.T) {
 	srv := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 		defer r.Body.Close()
 
-		if r.URL.Path == "/repos/someone/something" {
+		if r.URL.Path == "/api/v3/repos/someone/something" {
 			w.WriteHeader(http.StatusOK)
 			fmt.Fprint(w, `{"default_branch": "main"}`)
 			return
 		}
 
-		if r.URL.Path == "/repos/someone/something/contents/file.txt" && r.Method == http.MethodGet {
+		if r.URL.Path == "/api/v3/repos/someone/something/contents/file.txt" && r.Method == http.MethodGet {
 			w.WriteHeader(http.StatusNotFound)
 			return
 		}
 
-		if r.URL.Path == "/repos/someone/something/contents/file.txt" && r.Method == http.MethodPut {
+		if r.URL.Path == "/api/v3/repos/someone/something/contents/file.txt" && r.Method == http.MethodPut {
 			w.WriteHeader(http.StatusOK)
 			return
 		}
 
-		if r.URL.Path == "/rate_limit" {
+		if r.URL.Path == "/api/v3/rate_limit" {
 			w.WriteHeader(http.StatusOK)
 			fmt.Fprint(w, `{"resources":{"core":{"remaining":120}}}`)
 			return
@@ -773,9 +773,9 @@ func TestGitHubCreateFileHappyPathCreate(t *testing.T) {
 
 		t.Error("unhandled request: " + r.URL.Path)
 	}))
-	defer srv.Close()
+	t.Cleanup(srv.Close)
 
-	ctx := testctx.NewWithCfg(config.Project{
+	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
 			API: srv.URL + "/",
 		},
@@ -794,24 +794,24 @@ func TestGitHubCreateFileHappyPathUpdate(t *testing.T) {
 	srv := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 		defer r.Body.Close()
 
-		if r.URL.Path == "/repos/someone/something" {
+		if r.URL.Path == "/api/v3/repos/someone/something" {
 			w.WriteHeader(http.StatusOK)
 			fmt.Fprint(w, `{"default_branch": "main"}`)
 			return
 		}
 
-		if r.URL.Path == "/repos/someone/something/contents/file.txt" && r.Method == http.MethodGet {
+		if r.URL.Path == "/api/v3/repos/someone/something/contents/file.txt" && r.Method == http.MethodGet {
 			w.WriteHeader(http.StatusOK)
 			fmt.Fprint(w, `{"sha": "fake"}`)
 			return
 		}
 
-		if r.URL.Path == "/repos/someone/something/contents/file.txt" && r.Method == http.MethodPut {
+		if r.URL.Path == "/api/v3/repos/someone/something/contents/file.txt" && r.Method == http.MethodPut {
 			w.WriteHeader(http.StatusOK)
 			return
 		}
 
-		if r.URL.Path == "/rate_limit" {
+		if r.URL.Path == "/api/v3/rate_limit" {
 			w.WriteHeader(http.StatusOK)
 			fmt.Fprint(w, `{"resources":{"core":{"remaining":120}}}`)
 			return
@@ -819,9 +819,9 @@ func TestGitHubCreateFileHappyPathUpdate(t *testing.T) {
 
 		t.Error("unhandled request: " + r.URL.Path)
 	}))
-	defer srv.Close()
+	t.Cleanup(srv.Close)
 
-	ctx := testctx.NewWithCfg(config.Project{
+	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
 			API: srv.URL + "/",
 		},
@@ -840,39 +840,39 @@ func TestGitHubCreateFileFeatureBranchAlreadyExists(t *testing.T) {
 	srv := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 		defer r.Body.Close()
 
-		if r.URL.Path == "/repos/someone/something/branches/feature" && r.Method == http.MethodGet {
+		if r.URL.Path == "/api/v3/repos/someone/something/branches/feature" && r.Method == http.MethodGet {
 			w.WriteHeader(http.StatusNotFound)
 			return
 		}
 
-		if r.URL.Path == "/repos/someone/something/git/ref/heads/main" {
+		if r.URL.Path == "/api/v3/repos/someone/something/git/ref/heads/main" {
 			fmt.Fprint(w, `{"object": {"sha": "fake-sha"}}`)
 			return
 		}
 
-		if r.URL.Path == "/repos/someone/something/git/refs" && r.Method == http.MethodPost {
+		if r.URL.Path == "/api/v3/repos/someone/something/git/refs" && r.Method == http.MethodPost {
 			w.WriteHeader(http.StatusUnprocessableEntity)
 			fmt.Fprintf(w, `{"message": "Reference already exists"}`)
 			return
 		}
 
-		if r.URL.Path == "/repos/someone/something" {
+		if r.URL.Path == "/api/v3/repos/someone/something" {
 			w.WriteHeader(http.StatusOK)
 			fmt.Fprint(w, `{"default_branch": "main"}`)
 			return
 		}
 
-		if r.URL.Path == "/repos/someone/something/contents/file.txt" && r.Method == http.MethodGet {
+		if r.URL.Path == "/api/v3/repos/someone/something/contents/file.txt" && r.Method == http.MethodGet {
 			w.WriteHeader(http.StatusNotFound)
 			return
 		}
 
-		if r.URL.Path == "/repos/someone/something/contents/file.txt" && r.Method == http.MethodPut {
+		if r.URL.Path == "/api/v3/repos/someone/something/contents/file.txt" && r.Method == http.MethodPut {
 			w.WriteHeader(http.StatusOK)
 			return
 		}
 
-		if r.URL.Path == "/rate_limit" {
+		if r.URL.Path == "/api/v3/rate_limit" {
 			w.WriteHeader(http.StatusOK)
 			fmt.Fprint(w, `{"resources":{"core":{"remaining":120}}}`)
 			return
@@ -880,9 +880,9 @@ func TestGitHubCreateFileFeatureBranchAlreadyExists(t *testing.T) {
 
 		t.Error("unhandled request: " + r.Method + " " + r.URL.Path)
 	}))
-	defer srv.Close()
+	t.Cleanup(srv.Close)
 
-	ctx := testctx.NewWithCfg(config.Project{
+	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
 			API: srv.URL + "/",
 		},
@@ -902,38 +902,38 @@ func TestGitHubCreateFileFeatureBranchDoesNotExist(t *testing.T) {
 	srv := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 		defer r.Body.Close()
 
-		if r.URL.Path == "/repos/someone/something/branches/feature" && r.Method == http.MethodGet {
+		if r.URL.Path == "/api/v3/repos/someone/something/branches/feature" && r.Method == http.MethodGet {
 			w.WriteHeader(http.StatusNotFound)
 			return
 		}
 
-		if r.URL.Path == "/repos/someone/something/git/ref/heads/main" {
+		if r.URL.Path == "/api/v3/repos/someone/something/git/ref/heads/main" {
 			fmt.Fprint(w, `{"object": {"sha": "fake-sha"}}`)
 			return
 		}
 
-		if r.URL.Path == "/repos/someone/something/git/refs" && r.Method == http.MethodPost {
+		if r.URL.Path == "/api/v3/repos/someone/something/git/refs" && r.Method == http.MethodPost {
 			w.WriteHeader(http.StatusOK)
 			return
 		}
 
-		if r.URL.Path == "/repos/someone/something" {
+		if r.URL.Path == "/api/v3/repos/someone/something" {
 			w.WriteHeader(http.StatusOK)
 			fmt.Fprint(w, `{"default_branch": "main"}`)
 			return
 		}
 
-		if r.URL.Path == "/repos/someone/something/contents/file.txt" && r.Method == http.MethodGet {
+		if r.URL.Path == "/api/v3/repos/someone/something/contents/file.txt" && r.Method == http.MethodGet {
 			w.WriteHeader(http.StatusNotFound)
 			return
 		}
 
-		if r.URL.Path == "/repos/someone/something/contents/file.txt" && r.Method == http.MethodPut {
+		if r.URL.Path == "/api/v3/repos/someone/something/contents/file.txt" && r.Method == http.MethodPut {
 			w.WriteHeader(http.StatusOK)
 			return
 		}
 
-		if r.URL.Path == "/rate_limit" {
+		if r.URL.Path == "/api/v3/rate_limit" {
 			w.WriteHeader(http.StatusOK)
 			fmt.Fprint(w, `{"resources":{"core":{"remaining":120}}}`)
 			return
@@ -941,9 +941,9 @@ func TestGitHubCreateFileFeatureBranchDoesNotExist(t *testing.T) {
 
 		t.Error("unhandled request: " + r.Method + " " + r.URL.Path)
 	}))
-	defer srv.Close()
+	t.Cleanup(srv.Close)
 
-	ctx := testctx.NewWithCfg(config.Project{
+	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
 			API: srv.URL + "/",
 		},
@@ -959,13 +959,63 @@ func TestGitHubCreateFileFeatureBranchDoesNotExist(t *testing.T) {
 	require.NoError(t, client.CreateFile(ctx, config.CommitAuthor{}, repo, []byte("content"), "file.txt", "message"))
 }
 
+func TestGitHubCreateFileFeatureBranchNilObject(t *testing.T) {
+	srv := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+		defer r.Body.Close()
+
+		if r.URL.Path == "/api/v3/repos/someone/something/branches/feature" && r.Method == http.MethodGet {
+			w.WriteHeader(http.StatusNotFound)
+			return
+		}
+
+		if r.URL.Path == "/api/v3/repos/someone/something/git/ref/heads/main" {
+			// Return ref with nil object
+			fmt.Fprint(w, `{}`)
+			return
+		}
+
+		if r.URL.Path == "/api/v3/repos/someone/something" {
+			w.WriteHeader(http.StatusOK)
+			fmt.Fprint(w, `{"default_branch": "main"}`)
+			return
+		}
+
+		if r.URL.Path == "/api/v3/rate_limit" {
+			w.WriteHeader(http.StatusOK)
+			fmt.Fprint(w, `{"resources":{"core":{"remaining":120}}}`)
+			return
+		}
+
+		t.Error("unhandled request: " + r.Method + " " + r.URL.Path)
+	}))
+	t.Cleanup(srv.Close)
+
+	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
+		GitHubURLs: config.GitHubURLs{
+			API: srv.URL + "/",
+		},
+	})
+	client, err := newGitHub(ctx, "test-token")
+	require.NoError(t, err)
+	repo := Repo{
+		Owner:  "someone",
+		Name:   "something",
+		Branch: "feature",
+	}
+
+	err = client.CreateFile(ctx, config.CommitAuthor{}, repo, []byte("content"), "file.txt", "message")
+	require.Error(t, err)
+	require.Contains(t, err.Error(), "could not create ref")
+	require.Contains(t, err.Error(), "sha must be provided")
+}
+
 func TestGitHubCheckRateLimit(t *testing.T) {
 	now := time.Now().UTC()
 	reset := now.Add(1392 * time.Millisecond)
 	var first atomic.Bool
 	srv := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 		defer r.Body.Close()
-		if r.URL.Path == "/rate_limit" {
+		if r.URL.Path == "/api/v3/rate_limit" {
 			w.WriteHeader(http.StatusOK)
 			resetstr, _ := github.Timestamp{Time: reset}.MarshalJSON()
 			if first.Load() {
@@ -981,9 +1031,9 @@ func TestGitHubCheckRateLimit(t *testing.T) {
 		}
 		t.Error("unhandled request: " + r.Method + " " + r.URL.Path)
 	}))
-	defer srv.Close()
+	t.Cleanup(srv.Close)
 
-	ctx := testctx.NewWithCfg(config.Project{
+	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
 			API: srv.URL + "/",
 		},
@@ -998,12 +1048,12 @@ func TestGitHubCreateRelease(t *testing.T) {
 	srv := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 		defer r.Body.Close()
 
-		if r.URL.Path == "/repos/goreleaser/test/releases/tags/v1.0.0" {
+		if r.URL.Path == "/api/v3/repos/goreleaser/test/releases/tags/v1.0.0" {
 			w.WriteHeader(http.StatusNotFound)
 			return
 		}
 
-		if r.URL.Path == "/repos/goreleaser/test/releases" && r.Method == http.MethodPost {
+		if r.URL.Path == "/api/v3/repos/goreleaser/test/releases" && r.Method == http.MethodPost {
 			got, err := io.ReadAll(r.Body)
 			assert.NoError(t, err)
 			assert.JSONEq(t, `{"name": "v1.0.0", "tag_name": "v1.0.0", "target_commitish": "test", "body": "test release", "draft": true, "prerelease": false}`, string(got))
@@ -1013,7 +1063,7 @@ func TestGitHubCreateRelease(t *testing.T) {
 			return
 		}
 
-		if r.URL.Path == "/rate_limit" {
+		if r.URL.Path == "/api/v3/rate_limit" {
 			w.WriteHeader(http.StatusOK)
 			fmt.Fprint(w, `{"resources":{"core":{"remaining":120}}}`)
 			return
@@ -1021,9 +1071,9 @@ func TestGitHubCreateRelease(t *testing.T) {
 
 		t.Error("unhandled request: " + r.Method + " " + r.URL.Path)
 	}))
-	defer srv.Close()
+	t.Cleanup(srv.Close)
 
-	ctx := testctx.NewWithCfg(
+	ctx := testctx.WrapWithCfg(t.Context(),
 		config.Project{
 			GitHubURLs: config.GitHubURLs{
 				API: srv.URL + "/",
@@ -1054,7 +1104,7 @@ func TestGitHubCreateReleaseDeleteExistingDraft(t *testing.T) {
 	srv := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 		defer r.Body.Close()
 
-		if r.URL.Path == "/repos/goreleaser/test/releases" && r.Method == http.MethodGet {
+		if r.URL.Path == "/api/v3/repos/goreleaser/test/releases" && r.Method == http.MethodGet {
 			w.WriteHeader(http.StatusOK)
 			r, err := os.Open("testdata/github/releases.json")
 			if assert.NoError(t, err) {
@@ -1065,23 +1115,23 @@ func TestGitHubCreateReleaseDeleteExistingDraft(t *testing.T) {
 			return
 		}
 
-		if r.URL.Path == "/repos/goreleaser/test/releases/1" && r.Method == http.MethodDelete {
+		if r.URL.Path == "/api/v3/repos/goreleaser/test/releases/1" && r.Method == http.MethodDelete {
 			w.WriteHeader(http.StatusNoContent)
 			return
 		}
 
-		if r.URL.Path == "/repos/goreleaser/test/releases/tags/v1.0.0" {
+		if r.URL.Path == "/api/v3/repos/goreleaser/test/releases/tags/v1.0.0" {
 			w.WriteHeader(http.StatusNotFound)
 			return
 		}
 
-		if r.URL.Path == "/repos/goreleaser/test/releases" && r.Method == http.MethodPost {
+		if r.URL.Path == "/api/v3/repos/goreleaser/test/releases" && r.Method == http.MethodPost {
 			w.WriteHeader(http.StatusCreated)
 			fmt.Fprint(w, `{"id": 2, "html_url": "https://github.com/goreleaser/test/releases/v1.0.0"}`)
 			return
 		}
 
-		if r.URL.Path == "/rate_limit" {
+		if r.URL.Path == "/api/v3/rate_limit" {
 			w.WriteHeader(http.StatusOK)
 			fmt.Fprint(w, `{"resources":{"core":{"remaining":120}}}`)
 			return
@@ -1089,9 +1139,9 @@ func TestGitHubCreateReleaseDeleteExistingDraft(t *testing.T) {
 
 		t.Error("unhandled request: " + r.Method + " " + r.URL.Path)
 	}))
-	defer srv.Close()
+	t.Cleanup(srv.Close)
 
-	ctx := testctx.NewWithCfg(
+	ctx := testctx.WrapWithCfg(t.Context(),
 		config.Project{
 			GitHubURLs: config.GitHubURLs{
 				API: srv.URL + "/",
@@ -1123,13 +1173,13 @@ func TestGitHubCreateReleaseUpdateExisting(t *testing.T) {
 	srv := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 		defer r.Body.Close()
 
-		if r.URL.Path == "/repos/goreleaser/test/releases/tags/v1.0.0" {
+		if r.URL.Path == "/api/v3/repos/goreleaser/test/releases/tags/v1.0.0" {
 			w.WriteHeader(http.StatusOK)
 			fmt.Fprint(w, `{"id": 3, "name": "v1.0.0", "body": "This is an existing release"}`)
 			return
 		}
 
-		if r.URL.Path == "/repos/goreleaser/test/releases/3" && r.Method == http.MethodPatch {
+		if r.URL.Path == "/api/v3/repos/goreleaser/test/releases/3" && r.Method == http.MethodPatch {
 			got, err := io.ReadAll(r.Body)
 			assert.NoError(t, err)
 			assert.JSONEq(t, `{"name": "v1.0.0", "tag_name": "v1.0.0", "body": "This is an existing release", "prerelease": false}`, string(got))
@@ -1139,7 +1189,7 @@ func TestGitHubCreateReleaseUpdateExisting(t *testing.T) {
 			return
 		}
 
-		if r.URL.Path == "/rate_limit" {
+		if r.URL.Path == "/api/v3/rate_limit" {
 			w.WriteHeader(http.StatusOK)
 			fmt.Fprint(w, `{"resources":{"core":{"remaining":120}}}`)
 			return
@@ -1147,9 +1197,9 @@ func TestGitHubCreateReleaseUpdateExisting(t *testing.T) {
 
 		t.Error("unhandled request: " + r.Method + " " + r.URL.Path)
 	}))
-	defer srv.Close()
+	t.Cleanup(srv.Close)
 
-	ctx := testctx.NewWithCfg(
+	ctx := testctx.WrapWithCfg(t.Context(),
 		config.Project{
 			GitHubURLs: config.GitHubURLs{
 				API: srv.URL + "/",
@@ -1179,7 +1229,7 @@ func TestGitHubCreateReleaseUseExistingDraft(t *testing.T) {
 	srv := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 		defer r.Body.Close()
 
-		if r.URL.Path == "/repos/goreleaser/test/releases" && r.Method == http.MethodGet {
+		if r.URL.Path == "/api/v3/repos/goreleaser/test/releases" && r.Method == http.MethodGet {
 			w.WriteHeader(http.StatusOK)
 			r, err := os.Open("testdata/github/releases.json")
 			if assert.NoError(t, err) {
@@ -1190,7 +1240,7 @@ func TestGitHubCreateReleaseUseExistingDraft(t *testing.T) {
 			return
 		}
 
-		if r.URL.Path == "/repos/goreleaser/test/releases/1" && r.Method == http.MethodPatch {
+		if r.URL.Path == "/api/v3/repos/goreleaser/test/releases/1" && r.Method == http.MethodPatch {
 			got, err := io.ReadAll(r.Body)
 			assert.NoError(t, err)
 			assert.JSONEq(t, `{"name": "v1.0.0", "tag_name": "v1.0.0", "body": "Existing draft release", "draft": true, "prerelease": false}`, string(got))
@@ -1200,7 +1250,7 @@ func TestGitHubCreateReleaseUseExistingDraft(t *testing.T) {
 			return
 		}
 
-		if r.URL.Path == "/rate_limit" {
+		if r.URL.Path == "/api/v3/rate_limit" {
 			w.WriteHeader(http.StatusOK)
 			fmt.Fprint(w, `{"resources":{"core":{"remaining":120}}}`)
 			return
@@ -1208,9 +1258,9 @@ func TestGitHubCreateReleaseUseExistingDraft(t *testing.T) {
 
 		t.Error("unhandled request: " + r.Method + " " + r.URL.Path)
 	}))
-	defer srv.Close()
+	t.Cleanup(srv.Close)
 
-	ctx := testctx.NewWithCfg(
+	ctx := testctx.WrapWithCfg(t.Context(),
 		config.Project{
 			GitHubURLs: config.GitHubURLs{
 				API: srv.URL + "/",
@@ -1237,5 +1287,126 @@ func TestGitHubCreateReleaseUseExistingDraft(t *testing.T) {
 	require.Equal(t, "1", release)
 }
 
+func TestGitHubCreateFileWithGitHubAppToken(t *testing.T) {
+	srv := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+		defer r.Body.Close()
+
+		if r.URL.Path == "/api/v3/repos/someone/something" {
+			w.WriteHeader(http.StatusOK)
+			fmt.Fprint(w, `{"default_branch": "main"}`)
+			return
+		}
+
+		if r.URL.Path == "/api/v3/repos/someone/something/contents/file.txt" && r.Method == http.MethodGet {
+			w.WriteHeader(http.StatusNotFound)
+			return
+		}
+
+		if r.URL.Path == "/api/v3/repos/someone/something/contents/file.txt" && r.Method == http.MethodPut {
+			// Verify that committer is not set in the request
+			body, err := io.ReadAll(r.Body)
+			assert.NoError(t, err)
+
+			var reqData map[string]interface{}
+			assert.NoError(t, json.Unmarshal(body, &reqData))
+
+			// Verify committer is not present when using GitHub App token
+			_, hasCommitter := reqData["committer"]
+			assert.False(t, hasCommitter, "committer should not be set when using GitHub App token")
+
+			w.WriteHeader(http.StatusOK)
+			return
+		}
+
+		if r.URL.Path == "/api/v3/rate_limit" {
+			w.WriteHeader(http.StatusOK)
+			fmt.Fprint(w, `{"resources":{"core":{"remaining":120}}}`)
+			return
+		}
+
+		t.Error("unhandled request: " + r.URL.Path)
+	}))
+	t.Cleanup(srv.Close)
+
+	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
+		GitHubURLs: config.GitHubURLs{
+			API: srv.URL + "/",
+		},
+	})
+	client, err := newGitHub(ctx, "test-token")
+	require.NoError(t, err)
+	repo := Repo{
+		Owner: "someone",
+		Name:  "something",
+	}
+
+	require.NoError(t, client.CreateFile(ctx, config.CommitAuthor{
+		UseGitHubAppToken: true,
+	}, repo, []byte("content"), "file.txt", "message"))
+}
+
+func TestGitHubCreateFileWithoutGitHubAppToken(t *testing.T) {
+	srv := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+		defer r.Body.Close()
+
+		if r.URL.Path == "/api/v3/repos/someone/something" {
+			w.WriteHeader(http.StatusOK)
+			fmt.Fprint(w, `{"default_branch": "main"}`)
+			return
+		}
+
+		if r.URL.Path == "/api/v3/repos/someone/something/contents/file.txt" && r.Method == http.MethodGet {
+			w.WriteHeader(http.StatusNotFound)
+			return
+		}
+
+		if r.URL.Path == "/api/v3/repos/someone/something/contents/file.txt" && r.Method == http.MethodPut {
+			// Verify that committer is set in the request
+			body, err := io.ReadAll(r.Body)
+			assert.NoError(t, err)
+
+			var reqData map[string]interface{}
+			assert.NoError(t, json.Unmarshal(body, &reqData))
+
+			// Verify committer is present when not using GitHub App token
+			committer, hasCommitter := reqData["committer"]
+			assert.True(t, hasCommitter, "committer should be set when not using GitHub App token")
+
+			committerMap := committer.(map[string]interface{})
+			assert.Equal(t, "test-author", committerMap["name"])
+			assert.Equal(t, "test@example.com", committerMap["email"])
+
+			w.WriteHeader(http.StatusOK)
+			return
+		}
+
+		if r.URL.Path == "/api/v3/rate_limit" {
+			w.WriteHeader(http.StatusOK)
+			fmt.Fprint(w, `{"resources":{"core":{"remaining":120}}}`)
+			return
+		}
+
+		t.Error("unhandled request: " + r.URL.Path)
+	}))
+	t.Cleanup(srv.Close)
+
+	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
+		GitHubURLs: config.GitHubURLs{
+			API: srv.URL + "/",
+		},
+	})
+	client, err := newGitHub(ctx, "test-token")
+	require.NoError(t, err)
+	repo := Repo{
+		Owner: "someone",
+		Name:  "something",
+	}
+
+	require.NoError(t, client.CreateFile(ctx, config.CommitAuthor{
+		Name:  "test-author",
+		Email: "test@example.com",
+	}, repo, []byte("content"), "file.txt", "message"))
+}
+
 // TODO: test create upload file to release
 // TODO: test create PR
