@@ -331,7 +331,11 @@ func TestRunPipe_ArtifactoryDown(t *testing.T) {
 	})
 
 	require.NoError(t, Pipe{}.Default(ctx))
-	require.ErrorIs(t, Pipe{}.Publish(ctx), syscall.ECONNREFUSED)
+	err = Pipe{}.Publish(ctx)
+	require.Error(t, err)
+	if !testlib.IsWindows() {
+		require.ErrorIs(t, err, syscall.ECONNREFUSED)
+	}
 }
 
 func TestRunPipe_TargetTemplateError(t *testing.T) {
