@@ -10,6 +10,7 @@ import (
 	"github.com/goreleaser/goreleaser/v2/internal/client"
 	"github.com/goreleaser/goreleaser/v2/internal/git"
 	"github.com/goreleaser/goreleaser/v2/internal/golden"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe"
 	"github.com/goreleaser/goreleaser/v2/internal/skips"
 	"github.com/goreleaser/goreleaser/v2/internal/testctx"
 	"github.com/goreleaser/goreleaser/v2/internal/testlib"
@@ -81,7 +82,7 @@ func createTemplateData() templateData {
 
 func TestFullAur(t *testing.T) {
 	data := createTemplateData()
-	pkg, err := applyTemplate(testctx.NewWithCfg(config.Project{
+	pkg, err := applyTemplate(testctx.WrapWithCfg(t.Context(), config.Project{
 		ProjectName: "foo",
 	}), aurTemplateData, data)
 	require.NoError(t, err)
@@ -90,7 +91,7 @@ func TestFullAur(t *testing.T) {
 }
 
 func TestAurSimple(t *testing.T) {
-	pkg, err := applyTemplate(testctx.New(), aurTemplateData, createTemplateData())
+	pkg, err := applyTemplate(testctx.Wrap(t.Context()), aurTemplateData, createTemplateData())
 	require.NoError(t, err)
 	require.Contains(t, pkg, `# Maintainer: Ciclano <ciclano@example.com>`)
 	require.Contains(t, pkg, `# Maintainer: Cicrano <cicrano@example.com>`)
@@ -106,7 +107,7 @@ func TestAurSimple(t *testing.T) {
 func TestFullSrcInfo(t *testing.T) {
 	data := createTemplateData()
 	data.License = "MIT"
-	pkg, err := applyTemplate(testctx.NewWithCfg(config.Project{
+	pkg, err := applyTemplate(testctx.WrapWithCfg(t.Context(), config.Project{
 		ProjectName: "foo",
 	}), srcInfoTemplate, data)
 	require.NoError(t, err)
@@ -115,7 +116,7 @@ func TestFullSrcInfo(t *testing.T) {
 }
 
 func TestSrcInfoSimple(t *testing.T) {
-	pkg, err := applyTemplate(testctx.New(), srcInfoTemplate, createTemplateData())
+	pkg, err := applyTemplate(testctx.Wrap(t.Context()), srcInfoTemplate, createTemplateData())
 	require.NoError(t, err)
 	require.Contains(t, pkg, `pkgbase = test`)
 	require.Contains(t, pkg, `pkgname = test`)
@@ -158,6 +159,7 @@ func TestFullPipe(t *testing.T) {
 				ctx.Config.AURSources[0].OptDepends = []string{"wget: stuff", "foo: bar"}
 				ctx.Config.AURSources[0].Provides = []string{"git", "svn"}
 				ctx.Config.AURSources[0].Conflicts = []string{"libcurl", "cvs", "blah"}
+				ctx.Config.AURSources[0].Install = "./testdata/install.sh"
 			},
 		},
 		"default-gitlab": {
@@ -247,7 +249,7 @@ func TestFullPipe(t *testing.T) {
 			key := testlib.MakeNewSSHKey(t, "")
 
 			folder := t.TempDir()
-			ctx := testctx.NewWithCfg(
+			ctx := testctx.WrapWithCfg(t.Context(),
 				config.Project{
 					Dist:        folder,
 					ProjectName: name,
@@ -263,9 +265,9 @@ func TestFullPipe(t *testing.T) {
 					},
 					Env: []string{"FOO=foo_is_bar"},
 				},
-				testctx.WithCurrentTag("v1.0.1-foo"),
-				testctx.WithSemver(1, 0, 1, "foo"),
-				testctx.WithVersion("1.0.1-foo"),
+				testctx.WithCurrentTag("v1.0.1"),
+				testctx.WithSemver(1, 0, 1, ""),
+				testctx.WithVersion("1.0.1"),
 			)
 
 			tt.prepare(ctx)
@@ -276,7 +278,7 @@ func TestFullPipe(t *testing.T) {
 				Goarch:  "amd64",
 				Goamd64: "v3",
 				Type:    artifact.UploadableArchive,
-				Extra: map[string]interface{}{
+				Extra: map[string]any{
 					artifact.ExtraID:       "bar",
 					artifact.ExtraFormat:   "tar.gz",
 					artifact.ExtraBinaries: []string{"bar"},
@@ -289,7 +291,7 @@ func TestFullPipe(t *testing.T) {
 				Goarch:  "amd64",
 				Goamd64: "v1",
 				Type:    artifact.UploadableArchive,
-				Extra: map[string]interface{}{
+				Extra: map[string]any{
 					artifact.ExtraID:       "bar",
 					artifact.ExtraFormat:   "tar.gz",
 					artifact.ExtraBinaries: []string{"bar"},
@@ -301,7 +303,7 @@ func TestFullPipe(t *testing.T) {
 				Name: "sources.tar.gz",
 				Path: path,
 				Type: artifact.UploadableSourceArchive,
-				Extra: map[string]interface{}{
+				Extra: map[string]any{
 					artifact.ExtraID:       "foo",
 					artifact.ExtraFormat:   "tar.gz",
 					artifact.ExtraBinaries: []string{"name"},
@@ -352,7 +354,7 @@ func TestRunPipe(t *testing.T) {
 	key := testlib.MakeNewSSHKey(t, "")
 
 	folder := t.TempDir()
-	ctx := testctx.NewWithCfg(
+	ctx := testctx.WrapWithCfg(t.Context(),
 		config.Project{
 			Dist:        folder,
 			ProjectName: "foo",
@@ -364,6 +366,7 @@ func TestRunPipe(t *testing.T) {
 					IDs:         []string{"foo"},
 					GitURL:      url,
 					PrivateKey:  key,
+					Install:     "./testdata/install.sh",
 				},
 			},
 			GitHubURLs: config.GitHubURLs{
@@ -396,7 +399,7 @@ func TestRunPipe(t *testing.T) {
 			Path:    path,
 			Goamd64: "v1",
 			Type:    artifact.UploadableSourceArchive,
-			Extra: map[string]interface{}{
+			Extra: map[string]any{
 				artifact.ExtraID:       "foo",
 				artifact.ExtraFormat:   "tar.gz",
 				artifact.ExtraBinaries: []string{"foo"},
@@ -413,7 +416,11 @@ func TestRunPipe(t *testing.T) {
 	require.NoError(t, runAll(ctx, client))
 	require.NoError(t, Pipe{}.Publish(ctx))
 
-	requireEqualRepoFiles(t, folder, ".", "foo", url)
+	requireEqualRepoFilesMap(t, ".", url, map[string]string{
+		"PKGBUILD":    filepath.Join(folder, "aur", "foo.pkgbuild"),
+		".SRCINFO":    filepath.Join(folder, "aur", "foo.srcinfo"),
+		"foo.install": "./testdata/install.sh",
+	})
 }
 
 func TestRunPipeMultipleConfigurations(t *testing.T) {
@@ -421,11 +428,14 @@ func TestRunPipeMultipleConfigurations(t *testing.T) {
 	key := testlib.MakeNewSSHKey(t, "")
 
 	folder := t.TempDir()
-	ctx := testctx.NewWithCfg(
+	ctx := testctx.WrapWithCfg(t.Context(),
 		config.Project{
 			Dist:        folder,
 			ProjectName: "foo",
 			AURSources: []config.AURSource{
+				{
+					Disable: `{{printf "true"}}`,
+				},
 				{
 					Name:        "foo",
 					IDs:         []string{"foo"},
@@ -457,7 +467,7 @@ func TestRunPipeMultipleConfigurations(t *testing.T) {
 		Path:    path,
 		Goamd64: "v1",
 		Type:    artifact.UploadableSourceArchive,
-		Extra: map[string]interface{}{
+		Extra: map[string]any{
 			artifact.ExtraID:       "bar",
 			artifact.ExtraFormat:   "tar.gz",
 			artifact.ExtraBinaries: []string{"bar"},
@@ -470,7 +480,7 @@ func TestRunPipeMultipleConfigurations(t *testing.T) {
 		Goarch:  "amd64",
 		Goamd64: "v1",
 		Type:    artifact.UploadableSourceArchive,
-		Extra: map[string]interface{}{
+		Extra: map[string]any{
 			artifact.ExtraID:       "foo",
 			artifact.ExtraFormat:   "tar.gz",
 			artifact.ExtraBinaries: []string{"name"},
@@ -483,11 +493,11 @@ func TestRunPipeMultipleConfigurations(t *testing.T) {
 	client := client.NewMock()
 
 	require.NoError(t, Pipe{}.Default(ctx))
-	require.NoError(t, runAll(ctx, client))
+	require.True(t, pipe.IsSkip(runAll(ctx, client)), "should partially skip")
 	require.NoError(t, Pipe{}.Publish(ctx))
 
 	dir := t.TempDir()
-	_, err = git.Run(testctx.New(), "-C", dir, "clone", url, "repo")
+	_, err = git.Run(t.Context(), "-C", dir, "clone", url, "repo")
 	require.NoError(t, err)
 
 	require.FileExists(t, filepath.Join(dir, "repo", "foo", ".SRCINFO"))
@@ -497,7 +507,7 @@ func TestRunPipeMultipleConfigurations(t *testing.T) {
 }
 
 func TestRunPipeNoBuilds(t *testing.T) {
-	ctx := testctx.NewWithCfg(config.Project{
+	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		ProjectName: "foo",
 		AURSources:  []config.AURSource{{}},
 	}, testctx.GitHubTokenType)
@@ -511,7 +521,7 @@ func TestRunPipeWrappedInDirectory(t *testing.T) {
 	url := testlib.GitMakeBareRepository(t)
 	key := testlib.MakeNewSSHKey(t, "")
 	folder := t.TempDir()
-	ctx := testctx.NewWithCfg(
+	ctx := testctx.WrapWithCfg(t.Context(),
 		config.Project{
 			Dist:        folder,
 			ProjectName: "foo",
@@ -531,7 +541,7 @@ func TestRunPipeWrappedInDirectory(t *testing.T) {
 		Path:    path,
 		Goamd64: "v1",
 		Type:    artifact.UploadableSourceArchive,
-		Extra: map[string]interface{}{
+		Extra: map[string]any{
 			artifact.ExtraID:        "foo",
 			artifact.ExtraFormat:    "tar.gz",
 			artifact.ExtraBinaries:  []string{"foo"},
@@ -556,7 +566,7 @@ func TestRunPipeBinaryRelease(t *testing.T) {
 	url := testlib.GitMakeBareRepository(t)
 	key := testlib.MakeNewSSHKey(t, "")
 	folder := t.TempDir()
-	ctx := testctx.NewWithCfg(
+	ctx := testctx.WrapWithCfg(t.Context(),
 		config.Project{
 			Dist:        folder,
 			ProjectName: "foo",
@@ -576,7 +586,7 @@ func TestRunPipeBinaryRelease(t *testing.T) {
 		Path:    path,
 		Goamd64: "v1",
 		Type:    artifact.UploadableSourceArchive,
-		Extra: map[string]interface{}{
+		Extra: map[string]any{
 			artifact.ExtraID:     "foo",
 			artifact.ExtraFormat: "binary",
 			artifact.ExtraBinary: "foo",
@@ -600,7 +610,7 @@ func TestRunPipeNoUpload(t *testing.T) {
 	folder := t.TempDir()
 	testPublish := func(tb testing.TB, modifier func(ctx *context.Context)) {
 		tb.Helper()
-		ctx := testctx.NewWithCfg(
+		ctx := testctx.WrapWithCfg(t.Context(),
 			config.Project{
 				Dist:        folder,
 				ProjectName: "foo",
@@ -621,7 +631,7 @@ func TestRunPipeNoUpload(t *testing.T) {
 			Path:    path,
 			Goamd64: "v1",
 			Type:    artifact.UploadableSourceArchive,
-			Extra: map[string]interface{}{
+			Extra: map[string]any{
 				artifact.ExtraID:       "foo",
 				artifact.ExtraFormat:   "tar.gz",
 				artifact.ExtraBinaries: []string{"foo"},
@@ -654,7 +664,7 @@ func TestRunPipeNoUpload(t *testing.T) {
 
 func TestRunEmptyTokenType(t *testing.T) {
 	folder := t.TempDir()
-	ctx := testctx.NewWithCfg(
+	ctx := testctx.WrapWithCfg(t.Context(),
 		config.Project{
 			Dist:        folder,
 			ProjectName: "foo",
@@ -676,7 +686,7 @@ func TestRunEmptyTokenType(t *testing.T) {
 		Goos:   "linux",
 		Goarch: "amd64",
 		Type:   artifact.UploadableSourceArchive,
-		Extra: map[string]interface{}{
+		Extra: map[string]any{
 			artifact.ExtraID:       "foo",
 			artifact.ExtraFormat:   "tar.gz",
 			artifact.ExtraBinaries: []string{"foo"},
@@ -688,7 +698,7 @@ func TestRunEmptyTokenType(t *testing.T) {
 
 func TestDefault(t *testing.T) {
 	t.Run("empty", func(t *testing.T) {
-		ctx := testctx.NewWithCfg(config.Project{
+		ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 			ProjectName: "myproject",
 			AURSources:  []config.AURSource{{}},
 		}, testctx.GitHubTokenType)
@@ -710,7 +720,7 @@ func TestDefault(t *testing.T) {
 	})
 
 	t.Run("name-with-bin-suffix", func(t *testing.T) {
-		ctx := testctx.NewWithCfg(config.Project{
+		ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 			ProjectName: "myproject-bin",
 			AURSources: []config.AURSource{
 				{
@@ -736,7 +746,7 @@ func TestDefault(t *testing.T) {
 	})
 
 	t.Run("partial", func(t *testing.T) {
-		ctx := testctx.NewWithCfg(config.Project{
+		ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 			ProjectName: "myproject",
 			AURSources: []config.AURSource{
 				{
@@ -765,10 +775,10 @@ func TestDefault(t *testing.T) {
 
 func TestSkip(t *testing.T) {
 	t.Run("skip", func(t *testing.T) {
-		require.True(t, Pipe{}.Skip(testctx.New()))
+		require.True(t, Pipe{}.Skip(testctx.Wrap(t.Context())))
 	})
 	t.Run("skip flag", func(t *testing.T) {
-		ctx := testctx.NewWithCfg(config.Project{
+		ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 			AURSources: []config.AURSource{
 				{},
 			},
@@ -776,7 +786,7 @@ func TestSkip(t *testing.T) {
 		require.True(t, Pipe{}.Skip(ctx))
 	})
 	t.Run("dont skip", func(t *testing.T) {
-		ctx := testctx.NewWithCfg(config.Project{
+		ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 			AURSources: []config.AURSource{
 				{},
 			},
@@ -785,19 +795,16 @@ func TestSkip(t *testing.T) {
 	})
 }
 
-func requireEqualRepoFiles(tb testing.TB, distDir, repoDir, name, url string) {
+func requireEqualRepoFilesMap(tb testing.TB, repoDir, url string, files map[string]string) {
 	tb.Helper()
 	dir := tb.TempDir()
-	_, err := git.Run(testctx.New(), "-C", dir, "clone", url, "repo")
+	_, err := git.Run(tb.Context(), "-C", dir, "clone", url, "repo")
 	require.NoError(tb, err)
 
-	for reponame, ext := range map[string]string{
-		"PKGBUILD": ".pkgbuild",
-		".SRCINFO": ".srcinfo",
-	} {
-		path := filepath.Join(distDir, "aur", name+ext)
-		bts, err := os.ReadFile(path)
+	for reponame, distpath := range files {
+		bts, err := os.ReadFile(distpath)
 		require.NoError(tb, err)
+		ext := filepath.Ext(distpath)
 		golden.RequireEqualExt(tb, bts, ext)
 
 		bts, err = os.ReadFile(filepath.Join(dir, "repo", repoDir, reponame))
@@ -805,3 +812,11 @@ func requireEqualRepoFiles(tb testing.TB, distDir, repoDir, name, url string) {
 		golden.RequireEqualExt(tb, bts, ext)
 	}
 }
+
+func requireEqualRepoFiles(tb testing.TB, distDir, repoDir, name, url string) {
+	tb.Helper()
+	requireEqualRepoFilesMap(tb, repoDir, url, map[string]string{
+		"PKGBUILD": filepath.Join(distDir, "aur", name+".pkgbuild"),
+		".SRCINFO": filepath.Join(distDir, "aur", name+".srcinfo"),
+	})
+}
