@@ -5,6 +5,9 @@ import (
 	"fmt"
 
 	"github.com/Masterminds/semver/v3"
+	"github.com/caarlos0/log"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe"
+	"github.com/goreleaser/goreleaser/v2/internal/skips"
 	"github.com/goreleaser/goreleaser/v2/pkg/context"
 )
 
@@ -20,6 +23,12 @@ func (Pipe) String() string {
 func (Pipe) Run(ctx *context.Context) error {
 	sv, err := semver.NewVersion(ctx.Git.CurrentTag)
 	if err != nil {
+		if skips.Any(ctx, skips.Validate) {
+			log.WithError(err).
+				WithField("tag", ctx.Git.CurrentTag).
+				Warn("current tag is not semver")
+			return pipe.ErrSkipValidateEnabled
+		}
 		return fmt.Errorf("failed to parse tag '%s' as semver: %w", ctx.Git.CurrentTag, err)
 	}
 	ctx.Semver = context.Semver{
