@@ -89,6 +89,7 @@ func TestRunPipe(t *testing.T) {
 				PackageIdentifier:   "beckersoft.foo",
 				PublisherURL:        "https://carlosbecker.com",
 				PublisherSupportURL: "https://carlosbecker.com/support",
+				PrivacyURL:          "https://carlosbecker.com/privacy",
 				Copyright:           "bla bla bla",
 				CopyrightURL:        "https://goreleaser.com/copyright",
 				Author:              "Carlos Becker",
@@ -103,12 +104,13 @@ func TestRunPipe(t *testing.T) {
 				yadaa yada yada loooaaasssss
 
 				sss`,
-				Homepage:        "https://goreleaser.com",
-				License:         "MIT",
-				LicenseURL:      "https://goreleaser.com/eula/",
-				ReleaseNotesURL: "https://github.com/goreleaser/goreleaser/tags/{{.Tag}}",
-				ReleaseNotes:    "{{.Changelog}}",
-				Tags:            []string{"foo", "bar", "foo bar baz"},
+				Homepage:          "https://goreleaser.com",
+				License:           "MIT",
+				LicenseURL:        "https://goreleaser.com/eula/",
+				ReleaseNotesURL:   "https://github.com/goreleaser/goreleaser/tags/{{.Tag}}",
+				ReleaseNotes:      "{{.Changelog}}",
+				InstallationNotes: "https://goreleaser.com/install/",
+				Tags:              []string{"foo", "bar", "foo bar baz"},
 			},
 		},
 		{
@@ -119,6 +121,7 @@ func TestRunPipe(t *testing.T) {
 				Publisher:           "Beckersoft",
 				PublisherURL:        "https://carlosbecker.com",
 				PublisherSupportURL: "https://carlosbecker.com/support",
+				PrivacyURL:          "https://carlosbecker.com/privacy",
 				Copyright:           "bla bla bla",
 				CopyrightURL:        "https://goreleaser.com/copyright",
 				Author:              "Carlos Becker",
@@ -134,12 +137,13 @@ func TestRunPipe(t *testing.T) {
 				yadaa yada yada loooaaasssss
 
 				sss`,
-				Homepage:        "https://goreleaser.com",
-				License:         "MIT",
-				LicenseURL:      "https://goreleaser.com/eula/",
-				ReleaseNotesURL: "https://github.com/goreleaser/goreleaser/tags/{{.Tag}}",
-				ReleaseNotes:    "{{.Changelog}}",
-				Tags:            []string{"Foo", "bar", "FoO BaSiMdrR LAmd"},
+				Homepage:          "https://goreleaser.com",
+				License:           "MIT",
+				LicenseURL:        "https://goreleaser.com/eula/",
+				ReleaseNotesURL:   "https://github.com/goreleaser/goreleaser/tags/{{.Tag}}",
+				ReleaseNotes:      "{{.Changelog}}",
+				InstallationNotes: "https://goreleaser.com/install/",
+				Tags:              []string{"Foo", "bar", "FoO BaSiMdrR LAmd"},
 			},
 		},
 		{
@@ -745,10 +749,10 @@ func TestRunPipe(t *testing.T) {
 			}
 
 			require.NoError(t, pipe.runAll(ctx, client))
-			for _, winget := range ctx.Artifacts.Filter(artifact.Or(
-				artifact.ByType(artifact.WingetInstaller),
-				artifact.ByType(artifact.WingetVersion),
-				artifact.ByType(artifact.WingetDefaultLocale),
+			for _, winget := range ctx.Artifacts.Filter(artifact.ByTypes(
+				artifact.WingetInstaller,
+				artifact.WingetVersion,
+				artifact.WingetDefaultLocale,
 			)).List() {
 				bts, err := os.ReadFile(winget.Path)
 				require.NoError(t, err)
@@ -868,10 +872,10 @@ func TestFormatBinary(t *testing.T) {
 
 	require.NoError(t, pipe.Default(ctx))
 	require.NoError(t, pipe.runAll(ctx, client))
-	for _, winget := range ctx.Artifacts.Filter(artifact.Or(
-		artifact.ByType(artifact.WingetInstaller),
-		artifact.ByType(artifact.WingetVersion),
-		artifact.ByType(artifact.WingetDefaultLocale),
+	for _, winget := range ctx.Artifacts.Filter(artifact.ByTypes(
+		artifact.WingetInstaller,
+		artifact.WingetVersion,
+		artifact.WingetDefaultLocale,
 	)).List() {
 		bts, err := os.ReadFile(winget.Path)
 		require.NoError(t, err)
