@@ -1,6 +1,7 @@
 package shell_test
 
 import (
+	"os/exec"
 	"path/filepath"
 	"strings"
 	"testing"
@@ -22,6 +23,16 @@ func TestRunCommand(t *testing.T) {
 		))
 	})
 
+	t.Run("empty command", func(t *testing.T) {
+		require.NoError(t, shell.Run(
+			testctx.New(),
+			"",
+			[]string{},
+			[]string{},
+			false,
+		))
+	})
+
 	t.Run("cmd failed", func(t *testing.T) {
 		require.Error(t, shell.Run(
 			testctx.New(),
@@ -34,9 +45,15 @@ func TestRunCommand(t *testing.T) {
 
 	t.Run("cmd with output", func(t *testing.T) {
 		testlib.SkipIfWindows(t, "what would be a similar behavior in windows?")
+		err := shell.Run(
+			testctx.New(),
+			".",
+			[]string{"sh", "-c", `echo something; exit 1`},
+			[]string{},
+			true,
+		)
 		require.EqualError(
-			t,
-			shell.Run(testctx.New(), "", []string{"sh", "-c", `echo something; exit 1`}, []string{}, true),
+			t, err,
 			`shell: 'sh -c echo something; exit 1': exit status 1: something`,
 		)
 	})
@@ -44,7 +61,16 @@ func TestRunCommand(t *testing.T) {
 	t.Run("with env and dir", func(t *testing.T) {
 		testlib.SkipIfWindows(t, "what would be a similar behavior in windows?")
 		dir := t.TempDir()
-		require.NoError(t, shell.Run(testctx.New(), dir, []string{"sh", "-c", "touch $FOO"}, []string{"FOO=bar"}, false))
+		touch, err := exec.LookPath("touch")
+		require.NoError(t, err)
+		err = shell.Run(
+			testctx.New(),
+			dir,
+			[]string{"sh", "-c", touch + " $FOO"},
+			[]string{"FOO=bar"},
+			false,
+		)
+		require.NoError(t, err)
 		require.FileExists(t, filepath.Join(dir, "bar"))
 	})
 }
