@@ -7,8 +7,6 @@ import (
 	"io/fs"
 	"os"
 	"time"
-
-	"github.com/goreleaser/nfpm/v2"
 )
 
 type Versioned struct {
@@ -102,9 +100,6 @@ type PullRequestBase struct {
 	Branch string `yaml:"branch,omitempty" json:"branch,omitempty"`
 }
 
-// type alias to prevent stack overflowing in the custom unmarshaler.
-type pullRequestBase PullRequestBase
-
 type PullRequest struct {
 	Enabled bool            `yaml:"enabled,omitempty" json:"enabled,omitempty"`
 	Base    PullRequestBase `yaml:"base,omitempty" json:"base,omitempty"`
@@ -216,36 +211,36 @@ type Homebrew struct {
 
 // HomebrewCask contains the homebrew_casks section.
 type HomebrewCask struct {
-	Name                  string       `yaml:"name,omitempty" json:"name,omitempty"`
-	Repository            RepoRef      `yaml:"repository,omitempty" json:"repository,omitempty"`
-	CommitAuthor          CommitAuthor `yaml:"commit_author,omitempty" json:"commit_author,omitempty"`
-	CommitMessageTemplate string       `yaml:"commit_msg_template,omitempty" json:"commit_msg_template,omitempty"`
-	Directory             string       `yaml:"directory,omitempty" json:"directory,omitempty"`
-	Caveats               string       `yaml:"caveats,omitempty" json:"caveats,omitempty"`
-	Description           string       `yaml:"description,omitempty" json:"description,omitempty"`
-	Homepage              string       `yaml:"homepage,omitempty" json:"homepage,omitempty"`
-	License               string       `yaml:"license,omitempty" json:"license,omitempty"` // XXX: seems like casks don't support it?
-	SkipUpload            string       `yaml:"skip_upload,omitempty" json:"skip_upload,omitempty" jsonschema:"oneof_type=string;boolean"`
-	CustomBlock           string       `yaml:"custom_block,omitempty" json:"custom_block,omitempty"`
-	IDs                   []string     `yaml:"ids,omitempty" json:"ids,omitempty"`
-	Service               string       `yaml:"service,omitempty" json:"service,omitempty"`
+	Name                  string                   `yaml:"name,omitempty" json:"name,omitempty"`
+	Repository            RepoRef                  `yaml:"repository,omitempty" json:"repository,omitempty"`
+	CommitAuthor          CommitAuthor             `yaml:"commit_author,omitempty" json:"commit_author,omitempty"`
+	CommitMessageTemplate string                   `yaml:"commit_msg_template,omitempty" json:"commit_msg_template,omitempty"`
+	Directory             string                   `yaml:"directory,omitempty" json:"directory,omitempty"`
+	Caveats               string                   `yaml:"caveats,omitempty" json:"caveats,omitempty"`
+	Description           string                   `yaml:"description,omitempty" json:"description,omitempty"`
+	Homepage              string                   `yaml:"homepage,omitempty" json:"homepage,omitempty"`
+	SkipUpload            string                   `yaml:"skip_upload,omitempty" json:"skip_upload,omitempty" jsonschema:"oneof_type=string;boolean"`
+	CustomBlock           string                   `yaml:"custom_block,omitempty" json:"custom_block,omitempty"`
+	IDs                   []string                 `yaml:"ids,omitempty" json:"ids,omitempty"`
+	Service               string                   `yaml:"service,omitempty" json:"service,omitempty"`
+	Binaries              []string                 `yaml:"binaries,omitempty" json:"binaries,omitempty"`
+	Manpages              []string                 `yaml:"manpages,omitempty" json:"manpages,omitempty"`
+	URL                   HomebrewCaskURL          `yaml:"url,omitempty" json:"url,omitempty"`
+	Completions           HomebrewCaskCompletions  `yaml:"completions,omitempty" json:"completions,omitempty"`
+	Dependencies          []HomebrewCaskDependency `yaml:"dependencies,omitempty" json:"dependencies,omitempty"`
+	Conflicts             []HomebrewCaskConflict   `yaml:"conflicts,omitempty" json:"conflicts,omitempty"`
+	Hooks                 HomebrewCaskHooks        `yaml:"hooks,omitempty" json:"hooks,omitempty"`
+	Uninstall             HomebrewCaskUninstall    `yaml:"uninstall,omitempty" json:"uninstall,omitempty"`
+	Zap                   HomebrewCaskUninstall    `yaml:"zap,omitempty" json:"zap,omitempty"`
 
-	// Cask only:
-	Binaries     []string                 `yaml:"binaries,omitempty" json:"binaries,omitempty"`
-	Manpages     []string                 `yaml:"manpages,omitempty" json:"manpages,omitempty"`
-	URL          HomebrewCaskURL          `yaml:"url,omitempty" json:"url,omitempty"`
-	Completions  HomebrewCaskCompletions  `yaml:"completions,omitempty" json:"completions,omitempty"`
-	Dependencies []HomebrewCaskDependency `yaml:"dependencies,omitempty" json:"dependencies,omitempty"`
-	Conflicts    []HomebrewCaskConflict   `yaml:"conflicts,omitempty" json:"conflicts,omitempty"`
-	Hooks        HomebrewCaskHooks        `yaml:"hooks,omitempty" json:"hooks,omitempty"`
-	Uninstall    HomebrewCaskUninstall    `yaml:"uninstall,omitempty" json:"uninstall,omitempty"`
-	Zap          HomebrewCaskUninstall    `yaml:"zap,omitempty" json:"zap,omitempty"`
+	// XXX: casks don't yet support it, it has no effect.
+	License string `yaml:"license,omitempty" json:"license,omitempty"`
 
 	// Deprecated: use [HomebrewCask.Manpages] instead.
-	Manpage string `yaml:"manpage,omitempty" json:"manpage,omitempty"`
+	Manpage string `yaml:"manpage,omitempty" json:"manpage,omitempty" jsonschema:"deprecated=true"`
 
 	// Deprecated: use [HomebrewCask.Binaries] instead.
-	Binary string `yaml:"binary,omitempty" json:"binary,omitempty"`
+	Binary string `yaml:"binary,omitempty" json:"binary,omitempty" jsonschema:"deprecated=true"`
 }
 
 type HomebrewCaskURL struct {
@@ -283,7 +278,7 @@ type HomebrewCaskConflict struct {
 	Cask string `yaml:"cask,omitempty" json:"cask,omitempty"`
 
 	// Deprecated: by homebrew.
-	Formula string `yaml:"formula,omitempty" json:"formula,omitempty"`
+	Formula string `yaml:"formula,omitempty" json:"formula,omitempty" jsonschema:"deprecated=true"`
 }
 
 type HomebrewCaskDependency struct {
@@ -386,7 +381,6 @@ type Ko struct {
 	Labels              map[string]string `yaml:"labels,omitempty" json:"labels,omitempty"`
 	Annotations         map[string]string `yaml:"annotations,omitempty" json:"annotations,omitempty"`
 	User                string            `yaml:"user,omitempty" json:"user,omitempty"`
-	Repository          string            `yaml:"repository,omitempty" json:"repository,omitempty" jsonschema:"deprecated=true"` // Deprecated: use [Repositories].
 	Repositories        []string          `yaml:"repositories,omitempty" json:"repositories,omitempty"`
 	Platforms           []string          `yaml:"platforms,omitempty" json:"platforms,omitempty"`
 	Tags                []string          `yaml:"tags,omitempty" json:"tags,omitempty"`
@@ -404,6 +398,9 @@ type Ko struct {
 
 	// v2.7+
 	Disable string `yaml:"disable,omitempty" json:"disable,omitempty" jsonschema:"oneof_type=string;boolean"`
+
+	// Deprecated: use [Repositories].
+	Repository string `yaml:"repository,omitempty" json:"repository,omitempty" jsonschema:"deprecated=true"`
 }
 
 // Scoop contains the scoop.sh section.
@@ -429,9 +426,10 @@ type Scoop struct {
 
 // CommitAuthor is the author of a Git commit.
 type CommitAuthor struct {
-	Name    string        `yaml:"name,omitempty" json:"name,omitempty"`
-	Email   string        `yaml:"email,omitempty" json:"email,omitempty"`
-	Signing CommitSigning `yaml:"signing,omitempty" json:"signing,omitempty"`
+	Name              string        `yaml:"name,omitempty" json:"name,omitempty"`
+	Email             string        `yaml:"email,omitempty" json:"email,omitempty"`
+	Signing           CommitSigning `yaml:"signing,omitempty" json:"signing,omitempty"`
+	UseGitHubAppToken bool          `yaml:"use_github_app_token,omitempty" json:"use_github_app_token,omitempty"`
 }
 
 type CommitSigning struct {
@@ -487,7 +485,6 @@ type Build struct {
 	Builder         string          `yaml:"builder,omitempty" json:"builder,omitempty" jsonschema:"enum=,enum=go,enum=rust,enum=zig,enum=bun,enum=deno,enum=uv,enum=poetry"`
 	ModTimestamp    string          `yaml:"mod_timestamp,omitempty" json:"mod_timestamp,omitempty"`
 	Skip            string          `yaml:"skip,omitempty" json:"skip,omitempty" jsonschema:"oneof_type=string;boolean"`
-	GoBinary        string          `yaml:"gobinary,omitempty" json:"gobinary,omitempty"` // Deprecated: use [Build.Tool] instead.
 	Tool            string          `yaml:"tool,omitempty" json:"tool,omitempty"`
 	Command         string          `yaml:"command,omitempty" json:"command,omitempty"`
 	NoUniqueDistDir string          `yaml:"no_unique_dist_dir,omitempty" json:"no_unique_dist_dir,omitempty" jsonschema:"oneof_type=string;boolean"`
@@ -500,6 +497,9 @@ type Build struct {
 
 	// This is used internally only.
 	InternalDefaults BuildInternalDefaults `yaml:"-" json:"-"`
+
+	// Deprecated: use [Build.Tool] instead.
+	GoBinary string `yaml:"gobinary,omitempty" json:"gobinary,omitempty" jsonschema:"deprecated=true"`
 }
 
 type BuildInternalDefaults struct {
@@ -551,7 +551,7 @@ type FormatOverride struct {
 	Formats StringArray `yaml:"formats,omitempty" json:"formats,omitempty" jsonschema:"enum=tar,enum=tgz,enum=tar.gz,enum=zip,enum=gz,enum=tar.xz,enum=txz,enum=binary,enum=none,default=tar.gz"`
 
 	// Deprecated: use [Formats] instead.
-	Format string `yaml:"format,omitempty" json:"format,omitempty" jsonschema:"enum=tar,enum=tgz,enum=tar.gz,enum=zip,enum=gz,enum=tar.xz,enum=txz,enum=binary,enum=none,default=tar.gz"`
+	Format string `yaml:"format,omitempty" json:"format,omitempty" jsonschema:"enum=tar,enum=tgz,enum=tar.gz,enum=zip,enum=gz,enum=tar.xz,enum=txz,enum=binary,enum=none,default=tar.gz,deprecated=true"`
 }
 
 // File is a file inside an archive.
@@ -611,10 +611,10 @@ type Archive struct {
 	AllowDifferentBinaryCount bool             `yaml:"allow_different_binary_count,omitempty" json:"allow_different_binary_count,omitempty"`
 
 	// Deprecated: use [Formats] instead.
-	Format string `yaml:"format,omitempty" json:"format,omitempty" jsonschema:"enum=tar,enum=tgz,enum=tar.gz,enum=zip,enum=gz,enum=tar.xz,enum=txz,enum=binary,default=tar.gz"`
+	Format string `yaml:"format,omitempty" json:"format,omitempty" jsonschema:"enum=tar,enum=tgz,enum=tar.gz,enum=zip,enum=gz,enum=tar.xz,enum=txz,enum=binary,default=tar.gz,deprecated=true"`
 
 	// Deprecated: use [IDs] instead.
-	Builds []string `yaml:"builds,omitempty" json:"builds,omitempty"`
+	Builds []string `yaml:"builds,omitempty" json:"builds,omitempty" jsonschema:"deprecated=true"`
 }
 
 type ReleaseNotesMode string
@@ -689,7 +689,7 @@ type NFPM struct {
 	ParsedMTime time.Time `yaml:"-" json:"-"`
 
 	// Deprecated: use [IDs] instead.
-	Builds []string `yaml:"builds,omitempty" json:"builds,omitempty"`
+	Builds []string `yaml:"builds,omitempty" json:"builds,omitempty" jsonschema:"deprecated=true"`
 }
 
 type Libdirs struct {
@@ -808,14 +808,6 @@ type NFPMIPKAlternative struct {
 	LinkName string `yaml:"link_name,omitempty" json:"link_name,omitempty"`
 }
 
-func (alt NFPMIPKAlternative) ToNFP() nfpm.IPKAlternative {
-	return nfpm.IPKAlternative{
-		Priority: alt.Priority,
-		Target:   alt.Target,
-		LinkName: alt.LinkName,
-	}
-}
-
 type NFPMIPK struct {
 	ABIVersion    string               `yaml:"abi_version,omitempty" json:"abi_version,omitempty"`
 	Alternatives  []NFPMIPKAlternative `yaml:"alternatives,omitempty" json:"alternatives,omitempty"`
@@ -826,14 +818,6 @@ type NFPMIPK struct {
 	Fields        map[string]string    `yaml:"fields,omitempty" json:"fields,omitempty"`
 }
 
-func (ipk NFPMIPK) ToNFPAlts() []nfpm.IPKAlternative {
-	alts := make([]nfpm.IPKAlternative, len(ipk.Alternatives))
-	for i, alt := range ipk.Alternatives {
-		alts[i] = alt.ToNFP()
-	}
-	return alts
-}
-
 // NFPMOverridables is used to specify per package format settings.
 type NFPMOverridables struct {
 	FileNameTemplate string        `yaml:"file_name_template,omitempty" json:"file_name_template,omitempty"`
@@ -893,7 +877,7 @@ type Sign struct {
 	StdinFile   string   `yaml:"stdin_file,omitempty" json:"stdin_file,omitempty"`
 	Env         []string `yaml:"env,omitempty" json:"env,omitempty"`
 	Certificate string   `yaml:"certificate,omitempty" json:"certificate,omitempty"`
-	Output      bool     `yaml:"output,omitempty" json:"output,omitempty"`
+	Output      string   `yaml:"output,omitempty" json:"output,omitempty" jsonschema:"oneof_type=string;boolean"`
 }
 
 // BinarySign config.
@@ -908,7 +892,7 @@ type BinarySign struct {
 	StdinFile   string   `yaml:"stdin_file,omitempty" json:"stdin_file,omitempty"`
 	Env         []string `yaml:"env,omitempty" json:"env,omitempty"`
 	Certificate string   `yaml:"certificate,omitempty" json:"certificate,omitempty"`
-	Output      bool     `yaml:"output,omitempty" json:"output,omitempty"`
+	Output      string   `yaml:"output,omitempty" json:"output,omitempty" jsonschema:"oneof_type=string;boolean"`
 }
 
 type Notarize struct {
@@ -1007,7 +991,7 @@ type Snapcraft struct {
 	Files []SnapcraftExtraFiles `yaml:"extra_files,omitempty" json:"extra_files,omitempty"`
 
 	// Deprecated: use IDs.
-	Builds []string `yaml:"builds,omitempty" json:"builds,omitempty"`
+	Builds []string `yaml:"builds,omitempty" json:"builds,omitempty" jsonschema:"deprecated=true"`
 }
 
 // SnapcraftExtraFiles config.
@@ -1020,7 +1004,7 @@ type SnapcraftExtraFiles struct {
 // Snapshot config.
 type Snapshot struct {
 	// Deprecated: use VersionTemplate.
-	NameTemplate    string `yaml:"name_template,omitempty" json:"name_template,omitempty"`
+	NameTemplate    string `yaml:"name_template,omitempty" json:"name_template,omitempty" jsonschema:"deprecated=true"`
 	VersionTemplate string `yaml:"version_template,omitempty" json:"version_template,omitempty"`
 }
 
@@ -1043,6 +1027,7 @@ type Retry struct {
 }
 
 // Docker image config.
+//
 // Deprecated: use [DockerV2] instead.
 type Docker struct {
 	ID                 string   `yaml:"id,omitempty" json:"id,omitempty"`
@@ -1062,6 +1047,7 @@ type Docker struct {
 }
 
 // DockerManifest config.
+//
 // Deprecated: use [DockerV2] instead.
 type DockerManifest struct {
 	ID             string   `yaml:"id,omitempty" json:"id,omitempty"`
@@ -1206,54 +1192,52 @@ type Source struct {
 
 // Project includes all project configuration.
 type Project struct {
-	Version         int              `yaml:"version,omitempty" json:"version,omitempty" jsonschema:"enum=2,default=2"`
-	Pro             bool             `yaml:"pro,omitempty" json:"pro,omitempty"`
-	ProjectName     string           `yaml:"project_name,omitempty" json:"project_name,omitempty"`
-	Env             []string         `yaml:"env,omitempty" json:"env,omitempty"`
-	Release         Release          `yaml:"release,omitempty" json:"release,omitempty"`
-	Milestones      []Milestone      `yaml:"milestones,omitempty" json:"milestones,omitempty"`
-	Casks           []HomebrewCask   `yaml:"homebrew_casks,omitempty" json:"homebrew_casks,omitempty"`
-	Nix             []Nix            `yaml:"nix,omitempty" json:"nix,omitempty"`
-	Winget          []Winget         `yaml:"winget,omitempty" json:"winget,omitempty"`
-	AURs            []AUR            `yaml:"aurs,omitempty" json:"aurs,omitempty"`
-	AURSources      []AURSource      `yaml:"aur_sources,omitempty" json:"aur_sources,omitempty"`
-	Krews           []Krew           `yaml:"krews,omitempty" json:"krews,omitempty"`
-	Kos             []Ko             `yaml:"kos,omitempty" json:"kos,omitempty"`
-	Scoops          []Scoop          `yaml:"scoops,omitempty" json:"scoops,omitempty"`
-	Builds          []Build          `yaml:"builds,omitempty" json:"builds,omitempty"`
-	Archives        []Archive        `yaml:"archives,omitempty" json:"archives,omitempty"`
-	NFPMs           []NFPM           `yaml:"nfpms,omitempty" json:"nfpms,omitempty"`
-	Snapcrafts      []Snapcraft      `yaml:"snapcrafts,omitempty" json:"snapcrafts,omitempty"`
-	Snapshot        Snapshot         `yaml:"snapshot,omitempty" json:"snapshot,omitempty"`
-	Checksum        Checksum         `yaml:"checksum,omitempty" json:"checksum,omitempty"`
-	Dockers         []Docker         `yaml:"dockers,omitempty" json:"dockers,omitempty"`
-	DockersV2       []DockerV2       `yaml:"dockers_v2,omitempty" json:"dockers_v2,omitempty"`
-	DockerDigest    DockerDigest     `yaml:"docker_digest,omitempty" json:"docker_digest,omitempty"`
-	DockerManifests []DockerManifest `yaml:"docker_manifests,omitempty" json:"docker_manifests,omitempty"`
-	Artifactories   []Upload         `yaml:"artifactories,omitempty" json:"artifactories,omitempty"`
-	Uploads         []Upload         `yaml:"uploads,omitempty" json:"uploads,omitempty"`
-	Blobs           []Blob           `yaml:"blobs,omitempty" json:"blobs,omitempty"`
-	Publishers      []Publisher      `yaml:"publishers,omitempty" json:"publishers,omitempty"`
-	Changelog       Changelog        `yaml:"changelog,omitempty" json:"changelog,omitempty"`
-	Dist            string           `yaml:"dist,omitempty" json:"dist,omitempty"`
-	Signs           []Sign           `yaml:"signs,omitempty" json:"signs,omitempty"`
-	Notarize        Notarize         `yaml:"notarize,omitempty" json:"notarize,omitempty"`
-	DockerSigns     []Sign           `yaml:"docker_signs,omitempty" json:"docker_signs,omitempty"`
-	BinarySigns     []BinarySign     `yaml:"binary_signs,omitempty" json:"binary_signs,omitempty"`
-	EnvFiles        EnvFiles         `yaml:"env_files,omitempty" json:"env_files,omitempty"`
-	Before          Before           `yaml:"before,omitempty" json:"before,omitempty"`
-	Source          Source           `yaml:"source,omitempty" json:"source,omitempty"`
-	GoMod           GoMod            `yaml:"gomod,omitempty" json:"gomod,omitempty"`
-	Announce        Announce         `yaml:"announce,omitempty" json:"announce,omitempty"`
-	SBOMs           []SBOM           `yaml:"sboms,omitempty" json:"sboms,omitempty"`
-	Chocolateys     []Chocolatey     `yaml:"chocolateys,omitempty" json:"chocolateys,omitempty"`
-	Git             Git              `yaml:"git,omitempty" json:"git,omitempty"`
-	ReportSizes     bool             `yaml:"report_sizes,omitempty" json:"report_sizes,omitempty"`
-	Metadata        ProjectMetadata  `yaml:"metadata,omitempty" json:"metadata,omitempty"`
-
+	Version           int               `yaml:"version,omitempty" json:"version,omitempty" jsonschema:"enum=2,default=2"`
+	Pro               bool              `yaml:"pro,omitempty" json:"pro,omitempty"`
+	ProjectName       string            `yaml:"project_name,omitempty" json:"project_name,omitempty"`
+	Env               []string          `yaml:"env,omitempty" json:"env,omitempty"`
+	Release           Release           `yaml:"release,omitempty" json:"release,omitempty"`
+	Milestones        []Milestone       `yaml:"milestones,omitempty" json:"milestones,omitempty"`
+	Casks             []HomebrewCask    `yaml:"homebrew_casks,omitempty" json:"homebrew_casks,omitempty"`
+	Nix               []Nix             `yaml:"nix,omitempty" json:"nix,omitempty"`
+	Winget            []Winget          `yaml:"winget,omitempty" json:"winget,omitempty"`
+	AURs              []AUR             `yaml:"aurs,omitempty" json:"aurs,omitempty"`
+	AURSources        []AURSource       `yaml:"aur_sources,omitempty" json:"aur_sources,omitempty"`
+	Krews             []Krew            `yaml:"krews,omitempty" json:"krews,omitempty"`
+	Kos               []Ko              `yaml:"kos,omitempty" json:"kos,omitempty"`
+	Scoops            []Scoop           `yaml:"scoops,omitempty" json:"scoops,omitempty"`
+	Builds            []Build           `yaml:"builds,omitempty" json:"builds,omitempty"`
+	Archives          []Archive         `yaml:"archives,omitempty" json:"archives,omitempty"`
+	NFPMs             []NFPM            `yaml:"nfpms,omitempty" json:"nfpms,omitempty"`
+	Snapcrafts        []Snapcraft       `yaml:"snapcrafts,omitempty" json:"snapcrafts,omitempty"`
+	Snapshot          Snapshot          `yaml:"snapshot,omitempty" json:"snapshot,omitempty"`
+	Checksum          Checksum          `yaml:"checksum,omitempty" json:"checksum,omitempty"`
+	DockersV2         []DockerV2        `yaml:"dockers_v2,omitempty" json:"dockers_v2,omitempty"`
+	DockerDigest      DockerDigest      `yaml:"docker_digest,omitempty" json:"docker_digest,omitempty"`
+	Artifactories     []Upload          `yaml:"artifactories,omitempty" json:"artifactories,omitempty"`
+	Uploads           []Upload          `yaml:"uploads,omitempty" json:"uploads,omitempty"`
+	Blobs             []Blob            `yaml:"blobs,omitempty" json:"blobs,omitempty"`
+	Publishers        []Publisher       `yaml:"publishers,omitempty" json:"publishers,omitempty"`
+	Changelog         Changelog         `yaml:"changelog,omitempty" json:"changelog,omitempty"`
+	Dist              string            `yaml:"dist,omitempty" json:"dist,omitempty"`
+	Signs             []Sign            `yaml:"signs,omitempty" json:"signs,omitempty"`
+	Notarize          Notarize          `yaml:"notarize,omitempty" json:"notarize,omitempty"`
+	DockerSigns       []Sign            `yaml:"docker_signs,omitempty" json:"docker_signs,omitempty"`
+	BinarySigns       []BinarySign      `yaml:"binary_signs,omitempty" json:"binary_signs,omitempty"`
+	EnvFiles          EnvFiles          `yaml:"env_files,omitempty" json:"env_files,omitempty"`
+	Before            Before            `yaml:"before,omitempty" json:"before,omitempty"`
+	Source            Source            `yaml:"source,omitempty" json:"source,omitempty"`
+	GoMod             GoMod             `yaml:"gomod,omitempty" json:"gomod,omitempty"`
+	Announce          Announce          `yaml:"announce,omitempty" json:"announce,omitempty"`
+	SBOMs             []SBOM            `yaml:"sboms,omitempty" json:"sboms,omitempty"`
+	Chocolateys       []Chocolatey      `yaml:"chocolateys,omitempty" json:"chocolateys,omitempty"`
+	Git               Git               `yaml:"git,omitempty" json:"git,omitempty"`
+	ReportSizes       bool              `yaml:"report_sizes,omitempty" json:"report_sizes,omitempty"`
+	Metadata          ProjectMetadata   `yaml:"metadata,omitempty" json:"metadata,omitempty"`
 	Makeselfs         []Makeself        `yaml:"makeselfs,omitempty" json:"makeselfs,omitempty"`
 	UniversalBinaries []UniversalBinary `yaml:"universal_binaries,omitempty" json:"universal_binaries,omitempty"`
 	UPXs              []UPX             `yaml:"upx,omitempty" json:"upx,omitempty"`
+	MCP               MCP               `yaml:"mcp,omitempty" json:"mcp,omitempty"`
 
 	// force the SCM token to use when multiple are set
 	ForceToken string `yaml:"force_token,omitempty" json:"force_token,omitempty" jsonschema:"enum=github,enum=gitlab,enum=gitea,enum=,default="`
@@ -1268,7 +1252,13 @@ type Project struct {
 	GiteaURLs GiteaURLs `yaml:"gitea_urls,omitempty" json:"gitea_urls,omitempty"`
 
 	// Deprecated: use [Project.Casks] instead.
-	Brews []Homebrew `yaml:"brews,omitempty" json:"brews,omitempty"`
+	Brews []Homebrew `yaml:"brews,omitempty" json:"brews,omitempty" jsonschema:"deprecated=true"`
+
+	// Deprecated: use [DockersV2] instead.
+	Dockers []Docker `yaml:"dockers,omitempty" json:"dockers,omitempty" jsonschema:"deprecated=true"`
+
+	// Deprecated: use [DockersV2] instead.
+	DockerManifests []DockerManifest `yaml:"docker_manifests,omitempty" json:"docker_manifests,omitempty" jsonschema:"deprecated=true"`
 }
 
 type ProjectMetadata struct {
@@ -1298,6 +1288,7 @@ type Announce struct {
 	Webhook        Webhook        `yaml:"webhook,omitempty" json:"webhook,omitempty"`
 	OpenCollective OpenCollective `yaml:"opencollective,omitempty" json:"opencollective,omitempty"`
 	Bluesky        Bluesky        `yaml:"bluesky,omitempty" json:"bluesky,omitempty"`
+	Discourse      Discourse      `yaml:"discourse,omitempty" json:"discourse,omitempty"`
 }
 
 type Webhook struct {
@@ -1406,6 +1397,16 @@ type Bluesky struct {
 	MessageTemplate string `yaml:"message_template,omitempty" json:"message_template,omitempty"`
 }
 
+// Discourse represents the discourse portion of a GoReleaser.
+type Discourse struct {
+	Enabled         string `yaml:"enabled,omitempty" json:"enabled,omitempty" jsonschema:"oneof_type=string;boolean"`
+	TitleTemplate   string `yaml:"title_template,omitempty" json:"title_template,omitempty"`
+	MessageTemplate string `yaml:"message_template,omitempty" json:"message_template,omitempty"`
+	Server          string `yaml:"server,omitempty" json:"server,omitempty"`
+	CategoryID      int    `yaml:"category_id,omitempty" json:"category_id,omitempty"`
+	Username        string `yaml:"username,omitempty" json:"username,omitempty"`
+}
+
 // SlackBlock represents the untyped structure of a rich slack message layout.
 type SlackBlock struct {
 	Internal any
@@ -1476,3 +1477,44 @@ type MakeselfFile struct {
 	Destination string `yaml:"dst,omitempty" json:"dst,omitempty"`
 	StripParent bool   `yaml:"strip_parent,omitempty" json:"strip_parent,omitempty"`
 }
+
+// MCP server configuration.
+type MCP struct {
+	GitHub GitHubMCP `yaml:"github,omitempty" json:"github,omitempty"`
+}
+
+// GitHubMCP registry configuration.
+type GitHubMCP struct {
+	Name        string         `yaml:"name" json:"name"`
+	Title       string         `yaml:"title" json:"title"`
+	Description string         `yaml:"description,omitempty" json:"description,omitempty"`
+	Homepage    string         `yaml:"homepage,omitempty" json:"homepage,omitempty"`
+	Packages    []MCPPackage   `yaml:"packages,omitempty" json:"packages,omitempty"`
+	Transports  []MCPTransport `yaml:"transports,omitempty" json:"transports,omitempty"`
+	Disable     string         `yaml:"disable,omitempty" json:"disable,omitempty" jsonschema:"oneof_type=string;boolean"`
+	Repository  MCPRepository  `yaml:"repository,omitempty" json:"repository,omitempty"`
+	Auth        MCPAuth        `yaml:"auth" json:"auth"`
+}
+
+type MCPRepository struct {
+	URL       string `yaml:"url,omitempty" json:"url,omitempty" `
+	Source    string `yaml:"source,omitempty" json:"source,omitempty" jsonschema:"enum=github,enum=gitlab,enum=gitea"`
+	ID        string `yaml:"id,omitempty" json:"id,omitempty"`
+	Subfolder string `yaml:"subfolder,omitempty" json:"subfolder,omitempty"`
+}
+
+type MCPAuth struct {
+	Type  string `json:"type" yaml:"type,omitempty" jsonschema:"enum=none,enum=github,enum=github-oidc,default=none"`
+	Token string `yaml:"token,omitempty" json:"token,omitempty"`
+}
+
+// MCPPackage represents an MCP package configuration.
+type MCPPackage struct {
+	RegistryType string       `yaml:"registry_type" json:"registry_type" jsonschema:"enum=oci,enum=npm,enum=pypi,enum=nuget,enum=mcpb"`
+	Identifier   string       `yaml:"identifier" json:"identifier"`
+	Transport    MCPTransport `yaml:"transport" json:"transport"`
+}
+
+type MCPTransport struct {
+	Type string `yaml:"type,omitempty" json:"type,omitempty" jsonschema:"enum=stdio,enum=streamable-http,enum=sse"`
+}
