@@ -8,13 +8,15 @@ import (
 	"github.com/stretchr/testify/require"
 
 	// langs to init.
+	_ "github.com/goreleaser/goreleaser/v2/internal/builders/bun"
+	_ "github.com/goreleaser/goreleaser/v2/internal/builders/deno"
 	_ "github.com/goreleaser/goreleaser/v2/internal/builders/golang"
 	_ "github.com/goreleaser/goreleaser/v2/internal/builders/rust"
 	_ "github.com/goreleaser/goreleaser/v2/internal/builders/zig"
 )
 
 func TestSystemDependencies(t *testing.T) {
-	ctx := testctx.New()
+	ctx := testctx.Wrap(t.Context())
 	require.Equal(t, []string{"git"}, system{}.Dependencies(ctx))
 }
 
@@ -23,14 +25,18 @@ func TestSystemStringer(t *testing.T) {
 }
 
 func TestBuildDependencies(t *testing.T) {
-	ctx := testctx.NewWithCfg(config.Project{
+	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		Builds: []config.Build{
+			{Builder: "bun"},
+			{Builder: "deno"},
 			{Builder: "go"},
 			{Builder: "rust"},
 			{Builder: "zig"},
 		},
 	})
 	require.Equal(t, []string{
+		"bun",
+		"deno",
 		"go",
 		"cargo",
 		"rustup",
@@ -43,3 +49,11 @@ func TestBuildDependencies(t *testing.T) {
 func TestBuildStringer(t *testing.T) {
 	require.NotEmpty(t, builds{}.String())
 }
+
+func TestHealthCheckers(t *testing.T) {
+	require.NotEmpty(t, HealthCheckers)
+}
+
+func TestDependencyCheckers(t *testing.T) {
+	require.NotEmpty(t, DependencyCheckers)
+}
